# -*- coding: utf-8 -*-
"""
Created on Thu Nov 16 16:18:42 2023

@author: skiba
"""
###################import data###################
#Most speleothem data is publicly available and should be extracted from the SISALv2 database (https://researchdata.reading.ac.uk/256/) 
#Data from previously unpublished record obtained from stalagite M6_1_57 from Schratten cave, 
#Melchsee-Frutt cave system, Switzerland, can be found in the Supplementary material of the corresponding publication.
#For all other speleothem data please contact Christoph Spötl from the University of Innsbruck: christoph.spoetl@uibk.ac.at

#Alpine Ice Field simulation results are available on zenodo (https://zenodo.org/record/1423176 for Seguinot et al. (2018)
#and https://zenodo.org/records/8270674 for Jouvet et al. (2023), respectively. The simulations should be downloaded and placed 
#in the working directory.
 

import PySimpleGUI as sg
import xarray as xr 
import hyoga
import netCDF4
import scipy
import pandas as pd
import numpy as np
import matplotlib.pyplot as plt
import cartopy.crs as ccrs
import cartopy.feature as cfeature
import matplotlib as mpl
import scipy.stats as stats
import seaborn as sns
from matplotlib.patches import Rectangle
from mpl_toolkits.axes_grid1 import make_axes_locatable
from mpl_toolkits.mplot3d import Axes3D as ax
import matplotlib.ticker
from matplotlib.ticker import ScalarFormatter, FormatStrFormatter, StrMethodFormatter, MultipleLocator, AutoMinorLocator
from numpy import random
from matplotlib import cm
from matplotlib.colors import ListedColormap, LinearSegmentedColormap
import matplotlib.markers as mmarkers
from matplotlib.patches import Patch
from matplotlib.lines import Line2D
import matplotlib.lines as mlines
from netCDF4 import Dataset
from scipy import interpolate
from scipy.interpolate import RegularGridInterpolator , LinearNDInterpolator
from scipy.signal import butter, lfilter
import matplotlib.colors as clrs
from pyproj import Transformer
#import os
#os.chdir('C:\\')


def find_nearest(array, value):
    array = np.asarray(array)
    idx = np.nanargmin((np.abs(array - value)))
    return array[idx]

def find_nearestidx(array, value):
    array = np.asarray(array)
    idx = np.nanargmin((np.abs(array - value)))
    return idx

def find_2ndnearestidx(array, value):
    array = np.asarray(array)
    idx = np.argsort(np.abs(array-value))[1]#np.nanargmin((np.abs(array - value)))
    return idx

def find_2ndnearest(array, value):
    array = np.asarray(array)
    idx = np.argsort(np.abs(array-value))[1]#np.nanargmin((np.abs(array - value)))
    return array[idx]

def setdiff_sorted(array1,array2,assume_unique=False):
    ans = np.setdiff1d(array1,array2,assume_unique).tolist()
    if assume_unique:
        return sorted(ans)
    return ans


####################prepare list of cave sites lists###################
##(if more then one record per cave site, this will be a list of arrays of each site)##
#e.g. 
#Spannagel_d13C_all_indiv = [array1_d13C, array2_d13C])
#Spannagel_sampleages_indiv = [array1_ages, array2_ages])


# another you'll also need an array where all data is stacked
##(if more then one record per cave site exists, this will be an array where all data is stacked)##
#e.g.
#Schratten_d13C_all = np.hstack([array1_d13C, array2_d13C])
#Schratten_sampleages = np.hstack([array1_ages, array2_ages])


####################prepare speleo d13C list and array including all sites###################
sampleages_indiv = [Spannagel_sampleages_indiv, Baschg_sampleages_indiv, SHengste_sampleages_indiv, [TKS[:,1]/1000], Hoelloch_sampleages_indiv, Schneckenloch_sampleages_indiv, [HUN_14[:,0]/1000], Gassel_sampleages_indiv, Schratten_sampleages_indiv, KlausCramer_sampleages_indiv, Beatus_sampleages_indiv]
d13C_all_indiv = [Spannagel_d13C_all_indiv, Baschg_d13C_all_indiv, SHengste_d13C_all_indiv,  [TKS[:,2]], Hoelloch_d13C_all_indiv, Schneckenloch_d13C_all_indiv, [HUN_14[:,2]], Gassel_d13C_all_indiv, Schratten_d13C_all_indiv,  KlausCramer_d13C_all_indiv, Beatus_d13C_all_indiv] 
       
sampleages = [Spannagel_sampleages, Baschg_sampleages, SHengste_sampleages, Schafsloch_sampleages, (TKS[:,1]/1000), Hoelloch_sampleages, Schneckenloch_sampleages, HUN_14[:,0]/1000, Gassel_sampleages, Schratten_sampleages, Neo_sampleages, KlausCramer_sampleages, Beatus_sampleages]
d13C_all = [Spannagel_d13C_all, Baschg_d13C_all, SHengste_d13C_all, Schafsloch_d13C_all, TKS[:,2], Hoelloch_d13C_all, Schneckenloch_d13C_all, HUN_14[:,2], Gassel_d13C_all, Schratten_d13C_all, Neo_d13C_all, KlausCramer_d13C_all, Beatus_d13C_all] 
   

cavelats_entities = [47.08, 47.25, 46.75, 47.28, 47.38, 47.33, 47.54, 47.82, 46.78, 47.36, 46.69]
cavelongs_entities = [11.67, 9.67, 7.81, 13.08, 10.15, 9.87, 12.03, 13.84, 8.27, 10.11, 7.78]
cavenames_entities = ["Spannagel", "Baschg", "Sieben Hengste",  "Entrische Kirche", 
                      "Hölloch im Mahdtal", "Schneckenloch", "Grete-Ruth shaft", "Gassel", "Schratten", 
                       'Klaus-Cramer', 'Beatus']
elevation = [2512, 870, 1883, 1040, 1560, 1568, 1491, 1196, 1862,  1964, 1080] 
markerrr = ["*", "v", "^", "<",">","o","d","X","D", "p", "H"]

# Speleothem presence (age, growth) vs. pressure-adjusted temperature at the base. 
# Only for data points where speleothem d13C >= 1 permil and modelled ice thickness >20 m, which we interpret as glacier presence.


simulationsarray = ['alpcyc.2km.md01.pp.ex.1ka.nc', 'alpcyc.2km.md01.cp.ex.1ka.nc', 
                    'alpcyc.2km.grip.pp.ex.1ka.nc', 
                    'alpcyc.2km.grip.cp.ex.1ka.nc', 
                    'alpcyc.2km.epic.pp.ex.1ka.nc', 'alpcyc.1km.epic.pp.ex.1ka.nc', 'alpcyc.2km.epic.cp.ex.1ka.nc', 
                    'ex-AIF-paper.nc']


Ticethresh = -1
Tthresh1 = -1
Tthresh2 = -4

glacthick = 20

fail = []
all_thkkk = []
stddd = 2 #ka
stddd_stal = 1 #ka 
MCs = 1#00

transformer = Transformer.from_crs('epsg:4326','epsg:32632',always_xy=True) 

Segmd01pp_agree_MC_T = []
Segmd01cp_agree_MC_T = []
Seggrippp_agree_MC_T = []
Seggripcp_agree_MC_T = []
Segepicpp_agree_MC_T = []
Segepicpp1km_agree_MC_T = []
Segepiccp_agree_MC_T = []
Jouvet_agree_MC_T = []
Segmd01pp_disagree_MC_T = []
Segmd01cp_disagree_MC_T = []
Seggrippp_disagree_MC_T = []
Seggripcp_disagree_MC_T = []
Segepicpp_disagree_MC_T = []
Segepicpp1km_disagree_MC_T = []
Segepiccp_disagree_MC_T = []
Jouvet_disagree_MC_T = []

notworking_Segmd01pp = []
notworking_Segmd01cp = []
notworking_Seggrippp = []
notworking_Seggripcp = []
notworking_Segepicpp = []
notworking_Segepicpp1km = []
notworking_Segepiccp = []
notworking_Jouvet = []

working_Segmd01pp = []
working_Segmd01cp = []
working_Seggrippp = []
working_Seggripcp = []
working_Segepicpp = []
working_Segepicpp1km = []
working_Segepiccp = []
working_Jouvet = []
dontwork_all = []

for v in range(0,MCs):
    sg.one_line_progress_meter('This is my progress meter!', v+1, len(range(0,MCs)), '-key-')
    print(v)
    Segmd01pp_agree = []
    Segmd01pp_ddisagree = []
    Segmd01cp_agree = []
    Segmd01cp_ddisagree = []
    Seggrippp_agree = []
    Seggrippp_ddisagree = []
    Seggripcp_agree = []
    Seggripcp_ddisagree = []
    Segepicpp_agree = []
    Segepicpp_ddisagree = []
    Segepicpp1km_agree = []
    Segepicpp1km_ddisagree = []
    Segepiccp_agree = []
    Segepiccp_ddisagree = []
    Jouvet_agree = []
    Jouvet_ddisagree = []
    for data in simulationsarray: 
        ds = hyoga.open.dataset(data)
        nc    = Dataset(data, 'r')
        time2 = np.squeeze(nc.variables['time'][:])
        time = np.round((time2 / 31536000)/1000, 2) 
        a = np.round(stats.truncnorm((-1000000 - time[-1]) / stddd, (0 - time[-1]) / stddd, loc=time[-1], scale=stddd).rvs(1))
        b = np.round(random.normal(loc=time[0], scale=stddd, size=1))
        n = len(time)
        interval = time[2] - time[1]
        time_new = np.linspace(b,a,n)
        time = time_new[:,0]      
        x      = np.squeeze(nc.variables['x'])
        y      = np.squeeze(nc.variables['y'])
        topg = np.squeeze(nc.variables['topg'])            
        thk2 = np.squeeze(nc.variables['thk'])
        thk = np.select([thk2 == -2000000000.0], [0], thk2) 

        tempbase2 = np.squeeze(nc.variables['temppabase'])
        tempbase = np.squeeze(nc.variables['temppabase'])

        nc.close()
        TEMPBASE = RegularGridInterpolator((time, y, x), tempbase, bounds_error=False, fill_value=None, method="linear")#, method="linear")
        TOP = RegularGridInterpolator((time, y, x), topg, bounds_error=False, fill_value=None, method="linear")#, method="linear")
        THK = RegularGridInterpolator((time, y, x), thk, bounds_error=False, fill_value=None, method="linear")

        elev = []
        marker = []
        iceT_alltimepoints = []
        age_alltimepoints = []
        d13C_alltimepoints = []
        elev_alltimepoints = []
        iceTtest =[]
        work = []
        dontwork = []
        for g in range(0, len(cavelats_entities)):
            ax = plt.subplot(projection=ccrs.UTM(32))
            [handle] = ax.plot(cavelongs_entities[g], cavelats_entities[g], marker='*', color='black', markersize=6, transform=ccrs.Geodetic())
            t_path = handle._get_transformed_path()
            path_in_data_coords, _ = t_path.get_transformed_path_and_affine()
            print(path_in_data_coords.vertices)
            f = g
            Xval = transformer.transform(cavelongs_entities[g], cavelats_entities[g])[0]
            Yval = transformer.transform(cavelongs_entities[g], cavelats_entities[g])[1]
            X = find_nearestidx(ds.thk.x, transformer.transform(cavelongs_entities[g], cavelats_entities[g])[0])
            Y = find_nearestidx(ds.thk.y, transformer.transform(cavelongs_entities[g], cavelats_entities[g])[1])
            
            for i in range(0,len(sampleages_indiv[f])):
                a = random.normal(loc=np.min(sampleages_indiv[f][i]), scale=stddd_stal, size=1)
                b = random.normal(loc=np.max(sampleages_indiv[f][i]), scale=stddd_stal, size=1)
                n = len(sampleages_indiv[f][i])
                stalage_new = np.linspace(a,b,n)
                stalage = stalage_new[:,0]
                
                #prepare time interpolated arrays
                path_in_data_coords.vertices[0][0] = transformer.transform(cavelongs_entities[g], cavelats_entities[g])[0]
                path_in_data_coords.vertices[0][1] = transformer.transform(cavelongs_entities[g], cavelats_entities[g])[1]
                X = find_nearestidx(ds.temppabase.x, path_in_data_coords.vertices[0][0])
                Y = find_nearestidx(ds.temppabase.y, path_in_data_coords.vertices[0][1])
                                
                X1 = find_nearestidx(ds.thk.x, path_in_data_coords.vertices[0][0])
                Y1 = find_nearestidx(ds.thk.y, path_in_data_coords.vertices[0][1])
                top1 = int(ds.topg[int(find_nearestidx(ds.topg.age, sampleages[g][0])),Y1,X1].values)
                X2 = find_2ndnearestidx(ds.thk.x, path_in_data_coords.vertices[0][0])
                Y2 = find_nearestidx(ds.thk.y, path_in_data_coords.vertices[0][1])
                top2 = int(ds.topg[int(find_nearestidx(ds.topg.age, sampleages[g][0])),Y2,X2].values)
                X3 = find_nearestidx(ds.thk.x, path_in_data_coords.vertices[0][0])
                Y3 = find_2ndnearestidx(ds.thk.y, path_in_data_coords.vertices[0][1])
                top3 = int(ds.topg[int(find_nearestidx(ds.topg.age, sampleages[g][0])),Y3,X3].values)
                X4 = find_2ndnearestidx(ds.thk.x, path_in_data_coords.vertices[0][0])
                Y4 = find_2ndnearestidx(ds.thk.y, path_in_data_coords.vertices[0][1])
                top4 = int(ds.topg[int(find_nearestidx(ds.topg.age, sampleages[g][0])),Y4,X4].values)
    
                diff1 = (find_nearest(ds.thk.x, path_in_data_coords.vertices[0][0])- path_in_data_coords.vertices[0][0]) + (find_nearest(ds.thk.y, path_in_data_coords.vertices[0][1]) - path_in_data_coords.vertices[0][1])
                diff2 = (find_2ndnearest(ds.thk.x, path_in_data_coords.vertices[0][0])- path_in_data_coords.vertices[0][0]) + (find_nearest(ds.thk.y, path_in_data_coords.vertices[0][1]) - path_in_data_coords.vertices[0][1])
                diff3 = (find_nearest(ds.thk.x, path_in_data_coords.vertices[0][0])- path_in_data_coords.vertices[0][0]) + (find_2ndnearest(ds.thk.y, path_in_data_coords.vertices[0][1]) - path_in_data_coords.vertices[0][1])
                diff4 = (find_2ndnearest(ds.thk.x, path_in_data_coords.vertices[0][0])- path_in_data_coords.vertices[0][0]) + (find_2ndnearest(ds.thk.y, path_in_data_coords.vertices[0][1]) - path_in_data_coords.vertices[0][1])
  
                arg = np.argmin([np.abs(diff1), np.abs(diff2), np.abs(diff3), np.abs(diff4)])
                diffs = [abs(diff1), abs(diff2), abs(diff3), abs(diff4)]
                diffs__ = np.sort([abs(diff1), abs(diff2), abs(diff3), abs(diff4)])
                argg =  diffs.index(min(diffs))
                cord_x = [X1, X2, X3, X4]
                cord_y = [Y1, Y2, Y3, Y4]
                    
                s = set(diffs) 
                second_argg = find_nearestidx(diffs, sorted(s)[1])
                third_argg = find_nearestidx(diffs, sorted(s)[2])
                fourth_argg = setdiff_sorted(list(np.arange(0,len(cord_x),1)), list([argg, second_argg, third_argg]))[0]
                    
                temp_arg = ds.temppabase[:,cord_y[argg], cord_x[argg]].values
                temp_second_arg = ds.temppabase[:,cord_y[second_argg], cord_x[second_argg]].values
                temp_third_arg = ds.temppabase[:,cord_y[third_argg], cord_x[third_argg]].values
                temp_fourth_arg = ds.temppabase[:,cord_y[fourth_argg], cord_x[fourth_argg]].values
                
                inter_1 = interpolate.interp1d(time, temp_arg)
                inter_2 = interpolate.interp1d(time, temp_second_arg)
                inter_3 = interpolate.interp1d(time, temp_third_arg)
                inter_4 = interpolate.interp1d(time, temp_fourth_arg)
                
                thk_arg = thk[:,cord_y[argg], cord_x[argg]]
                thk_second_arg = thk[:,cord_y[second_argg], cord_x[second_argg]]
                thk_third_arg = thk[:,cord_y[third_argg], cord_x[third_argg]]
                thk_fourth_arg = thk[:,cord_y[fourth_argg], cord_x[fourth_argg]]
            
                for u in range(0,len(stalage)):
                #with checking ice thickness
                #first check if ice thickness > 0 

                    if -np.min(time) < 115:
                        fff = -np.min(time) 
                    elif -np.min(time) > 115:
                        fff = 115 
                     
                    if stalage[u] > 12 and stalage[u] < fff:
                        #interpolate topography
                        #then pick your cave site like x0, y0,
                        #and then the interpolate dthickness there must be THK(x0, y0) or sth like this 

                        pts = (-stalage[u], Yval, Xval)

                        top = TOP(pts)
                        thkkk = THK(pts)
                        all_thkkk.append(thkkk)
                        if d13C_all_indiv[f][i][u] < -1 and thkkk <= glacthick:
                            pass
                        else: 
                                #if ice thickness > 0 sample T at base        
                                temppabaseee1 = inter_1(-stalage[u])
                                temppabaseee2 = inter_2(-stalage[u])
                                temppabaseee3 = inter_3(-stalage[u])
                                temppabaseee4 = inter_4(-stalage[u])
                                    
                                    
                                thk1 = thk_arg[find_nearestidx(time, -stalage[u])]                
                                thk2 = thk_second_arg[find_nearestidx(time, -stalage[u])]    
                                thk3 = thk_third_arg[find_nearestidx(time, -stalage[u])]                
                                thk4 = thk_fourth_arg[find_nearestidx(time, -stalage[u])]    
                                
                                thk1_2nd = thk_arg[find_2ndnearestidx(time, -stalage[u])]                
                                thk2_2nd = thk_second_arg[find_2ndnearestidx(time, -stalage[u])]    
                                thk3_2nd = thk_third_arg[find_2ndnearestidx(time, -stalage[u])]                
                                thk4_2nd = thk_fourth_arg[find_2ndnearestidx(time, -stalage[u])]    
                                
                                arr = np.array([thk1, thk2, thk3, thk4, thk1_2nd, thk2_2nd, thk3_2nd, thk4_2nd])

                                if sum(i > 0 for i in arr) != len(arr):
                                    if data == 'C:/Users/skiba/Downloads/alpcyc.2km.md01.pp.ex.1ka.nc':
                                        notworking_Segmd01pp.append(arr) 
                                    elif data == 'C:/Users/skiba/Downloads/alpcyc.2km.md01.cp.ex.1ka.nc':
                                        notworking_Segmd01cp.append(arr) 
                                    elif data == 'C:/Users/skiba/Downloads/alpcyc.2km.grip.pp.ex.1ka.nc':
                                        notworking_Seggrippp.append(arr) 
                                    elif data == 'C:/Users/skiba/Downloads/alpcyc.2km.grip.cp.ex.1ka.nc':
                                        notworking_Seggripcp.append(arr) 
                                    elif data == 'C:/Users/skiba/Downloads/alpcyc.2km.epic.pp.ex.1ka.nc':
                                        notworking_Segepicpp.append(arr)   
                                    elif data == 'C:/Users/skiba/Downloads/alpcyc.1km.epic.pp.ex.1ka.nc':
                                        notworking_Segepicpp1km.append(arr) 
                                    elif data == 'C:/Users/skiba/Downloads/alpcyc.2km.epic.cp.ex.1ka.nc':
                                        notworking_Segepiccp.append(arr) 
                                    elif data == 'C:/Users/skiba/Downloads/ex-AIF-paper.nc':
                                        notworking_Jouvet.append(arr) 
                                elif temppabaseee1 < -50 and temppabaseee2 < -50 and temppabaseee3 < -50 and temppabaseee4 < -50:
                                    dontwork.append([temppabaseee1, temppabaseee2, temppabaseee3, temppabaseee4])
                                    dontwork_all.append([temppabaseee1, temppabaseee2, temppabaseee3, temppabaseee4])
                                else:
                                    arr = np.array([temppabaseee1, temppabaseee2, temppabaseee3, temppabaseee4])
                                    work.append(arr)
                                    if data == 'C:/Users/skiba/Downloads/alpcyc.2km.md01.pp.ex.1ka.nc':
                                        working_Segmd01pp.append(arr) 
                                    elif data == 'C:/Users/skiba/Downloads/alpcyc.2km.md01.cp.ex.1ka.nc':
                                        working_Segmd01cp.append(arr) 
                                    elif data == 'C:/Users/skiba/Downloads/alpcyc.2km.grip.pp.ex.1ka.nc':
                                        working_Seggrippp.append(arr) 
                                    elif data == 'C:/Users/skiba/Downloads/alpcyc.2km.grip.cp.ex.1ka.nc':
                                        working_Seggripcp.append(arr) 
                                    elif data == 'C:/Users/skiba/Downloads/alpcyc.2km.epic.pp.ex.1ka.nc':
                                        working_Segepicpp.append(arr)   
                                    elif data == 'C:/Users/skiba/Downloads/alpcyc.1km.epic.pp.ex.1ka.nc':
                                        working_Segepicpp1km.append(arr) 
                                    elif data == 'C:/Users/skiba/Downloads/alpcyc.2km.epic.cp.ex.1ka.nc':
                                        working_Segepiccp.append(arr) 
                                    elif data == 'C:/Users/skiba/Downloads/ex-AIF-paper.nc':
                                        working_Jouvet.append(arr) 
                                    yy = []
                                    xx = []
                                    values = []
                                    
                                    yy.append(ds.temppabase.y[cord_y[argg]].values)
                                    xx.append(ds.temppabase.x[cord_x[argg]].values)
                                    values.append(temppabaseee1)
                                    
                                    yy.append(ds.temppabase.y[cord_y[second_argg]].values)
                                    xx.append(ds.temppabase.x[cord_x[second_argg]].values)
                                    values.append(temppabaseee2)
                                    
                                    yy.append(ds.temppabase.y[cord_y[third_argg]].values)
                                    xx.append(ds.temppabase.x[cord_x[third_argg]].values)
                                    values.append(temppabaseee3)
                                    
                                    yy.append(ds.temppabase.y[cord_y[fourth_argg]].values)
                                    xx.append(ds.temppabase.x[cord_x[fourth_argg]].values)
                                    values.append(temppabaseee4)

                                        
                                    iiinterp = interpolate.LinearNDInterpolator(list(zip(yy, xx)), values)
                                    temppabaseee = iiinterp(Yval, Xval)
                                        
                                    iceT_alltimepoints.append(temppabaseee)
                                    age_alltimepoints.append(stalage[u])
                                    d13C_alltimepoints.append(d13C_all_indiv[f][i][u])
                                    elev_alltimepoints.append(elevation[f])
                                    elev.append(elevation[f])
                                    marker.append(markerrr[f])
                                if data == 'C:/Users/skiba/Downloads/alpcyc.2km.md01.pp.ex.1ka.nc':
                                    if temppabaseee >= Ticethresh:
                                        Segmd01pp_agree.append(temppabaseee) 
                                    else:
                                        Segmd01pp_ddisagree.append(temppabaseee) 
                                elif data == 'C:/Users/skiba/Downloads/alpcyc.2km.md01.cp.ex.1ka.nc':
                                    if temppabaseee >= Ticethresh:
                                        Segmd01cp_agree.append(temppabaseee) 
                                    else:
                                        Segmd01cp_ddisagree.append(temppabaseee) 
                                                    
                                elif data == 'C:/Users/skiba/Downloads/alpcyc.2km.grip.pp.ex.1ka.nc':
                                    if temppabaseee >= Ticethresh:
                                        Seggrippp_agree.append(temppabaseee) 
                                    else:
                                        Seggrippp_ddisagree.append(temppabaseee) 
                                elif data == 'C:/Users/skiba/Downloads/alpcyc.2km.grip.cp.ex.1ka.nc':
                                    if temppabaseee >= Ticethresh:
                                        Seggripcp_agree.append(temppabaseee) 
                                    else:
                                        Seggripcp_ddisagree.append(temppabaseee) 
                                            
                                elif data == 'C:/Users/skiba/Downloads/alpcyc.2km.epic.pp.ex.1ka.nc':
                                    if temppabaseee >= Ticethresh:
                                        Segepicpp_agree.append(temppabaseee) 
                                    else:
                                        Segepicpp_ddisagree.append(temppabaseee) 
                                                
                                elif data == 'C:/Users/skiba/Downloads/alpcyc.1km.epic.pp.ex.1ka.nc':
                                    if temppabaseee >= Ticethresh:
                                        Segepicpp1km_agree.append(temppabaseee) 
                                    else:
                                        Segepicpp1km_ddisagree.append(temppabaseee)             
                                    
                                elif data == 'C:/Users/skiba/Downloads/alpcyc.2km.epic.cp.ex.1ka.nc':
                                    if temppabaseee >= Ticethresh:
                                        Segepiccp_agree.append(temppabaseee) 
                                    else:
                                        Segepiccp_ddisagree.append(temppabaseee)                         
                                elif data == 'C:/Users/skiba/Downloads/ex-AIF-paper.nc':
                                    if temppabaseee >= Ticethresh:
                                        Jouvet_agree.append(temppabaseee) 
                                    else:
                                        Jouvet_ddisagree.append(temppabaseee)    

                                   
                    
        if data == 'C:/Users/skiba/Downloads/alpcyc.2km.md01.pp.ex.1ka.nc':
            Segmd01pp = np.array(iceT_alltimepoints) 
            Segmd01pp_work = np.array(work) 
            Segmd01pp_dontwork = np.array(dontwork) 
        elif data == 'C:/Users/skiba/Downloads/alpcyc.2km.md01.cp.ex.1ka.nc':
            Segmd01cp = np.array(iceT_alltimepoints)  
            Segmd01cp_work = np.array(work) 
            Segmd01cp_dontwork = np.array(dontwork) 
        if data == 'C:/Users/skiba/Downloads/alpcyc.2km.grip.pp.ex.1ka.nc':
            Seggrippp = np.array(iceT_alltimepoints) 
            Seggrippp_work = np.array(work) 
            Seggrippp_dontwork = np.array(dontwork) 
        elif data == 'C:/Users/skiba/Downloads/alpcyc.2km.grip.cp.ex.1ka.nc':
            Seggripcp = np.array(iceT_alltimepoints)  
            Seggripcp_work = np.array(work) 
            Seggripcp_dontwork = np.array(dontwork) 
        elif data == 'C:/Users/skiba/Downloads/alpcyc.2km.epic.pp.ex.1ka.nc':
            Segepicpp = np.array(iceT_alltimepoints)  
            Segepicpp_work = np.array(work) 
            Segepicpp_dontwork = np.array(dontwork) 
        elif data == 'C:/Users/skiba/Downloads/alpcyc.1km.epic.pp.ex.1ka.nc':
            Segepicpp1km = np.array(iceT_alltimepoints) 
            Segepicpp1km_work = np.array(work) 
            Segepicpp1km_dontwork = np.array(dontwork)
        elif data == 'C:/Users/skiba/Downloads/alpcyc.2km.epic.cp.ex.1ka.nc':
            Segepiccp = np.array(iceT_alltimepoints)  
            Segepiccp_work = np.array(work) 
            Segepiccp_dontwork = np.array(dontwork)
        elif data == 'C:/Users/skiba/Downloads/ex-AIF-paper.nc':
            Jouvet = np.array(iceT_alltimepoints)  
            Jouvet_work = np.array(work) 
            Jouvet_dontwork = np.array(dontwork)

    Segmd01pp_agree_MC_T.append(Segmd01pp_agree)
    Segmd01pp_disagree_MC_T.append(Segmd01pp_ddisagree)
    Segmd01cp_agree_MC_T.append(Segmd01cp_agree)
    Segmd01cp_disagree_MC_T.append(Segmd01cp_ddisagree)
    Seggrippp_agree_MC_T.append(Seggrippp_agree)
    Seggrippp_disagree_MC_T.append(Seggrippp_ddisagree)
    Seggripcp_agree_MC_T.append(Seggripcp_agree)
    Seggripcp_disagree_MC_T.append(Seggripcp_ddisagree)
    Segepicpp_agree_MC_T.append(Segepicpp_agree)
    Segepicpp_disagree_MC_T.append(Segepicpp_ddisagree)
    Segepicpp1km_agree_MC_T.append(Segepicpp1km_agree)
    Segepicpp1km_disagree_MC_T.append(Segepicpp1km_ddisagree)
    Segepiccp_agree_MC_T.append(Segepiccp_agree)
    Segepiccp_disagree_MC_T.append(Segepiccp_ddisagree)
    Jouvet_agree_MC_T.append(Jouvet_agree)
    Jouvet_disagree_MC_T.append(Jouvet_ddisagree)
                              

                              

#kernel density plot for one age-ensemble member
mpl.style.use('default')
fig = plt.subplots(figsize=(10, 7))
allsimuiceTdata =({'Seguinot et al., Iberian Margin, cp': Segmd01cp, 'Seguinot et al., Iberian Margin, pp': Segmd01pp, 'Seguinot et al., GRIP, cp': Seggripcp, 'Seguinot et al., GRIP, pp': Seggrippp, 'Seguinot et al., EPICA, cp':Segepiccp, 'Seguinot et al., EPICA, pp':Segepicpp, 'Seguinot et al., EPICA, pp, 1 km':Segepicpp1km, 'Jouvet et al., EPICA':Jouvet})
allsimuiceT = pd.concat([pd.DataFrame(v, columns=[k]) for k, v in allsimuiceTdata.items()], axis=1)

# List of results for all simulation to plot
simulationsss = ['Seguinot et al., Iberian Margin, cp', 'Seguinot et al., Iberian Margin, pp', 'Seguinot et al., GRIP, cp', 'Seguinot et al., GRIP, pp', 'Seguinot et al., EPICA, cp',
         'Seguinot et al., EPICA, pp', 'Seguinot et al., EPICA, pp, 1 km','Jouvet et al., EPICA']

# List of colors
colors = clrs.ListedColormap(['#1b9e77', '#7EF2C7','#d95f02', '#FFB05C', '#7570b3', '#ABA4EB', '#E3DBFF', '#282A65'])
colorarray = colors
# Iterate through the simulations
i = -1
for simulation in simulationsss:
    i = i+1
    # Subset to the simulationss
    subset = allsimuiceT[simulation]
    
    # Draw the density plot
    sns.distplot(subset, hist = False, kde = True, norm_hist=True,
                 kde_kws = {'linewidth': 5}, color= tuple(colorarray(i)),
                 label = simulation)
    
# Plot formatting
leg = plt.legend(prop={'size': 13}, ncol=1, loc="upper left")
leg.set_title('Simulation',prop={'size':14, 'weight':"bold"})
#plt.plot([-1,-1], [0,5], color="black", linestyle="dashed")
plt.xlim(-8, 2)#(-8, 0.5)
plt.ylim(0,1)
#plt.title('Density Plots of pressure-adjusted temperature at the base of the ice for all simulations')
plt.xlabel('Pressure-adjusted temperature at the base [°C]', fontsize=18, weight="bold")
plt.ylabel('Density', fontsize=18, weight="bold")
plt.xticks(fontsize=18)
plt.yticks(fontsize=18)

plt.savefig("paper/NorthAlpsSpeleo_growthvsTatbase_allsimus_kde_icethick20m_wGRIP_only12to115ka_20230526_newinterp.png", dpi=350, bbox_inches = 'tight')


#####warm or cold glacier base #####
####age uncertain
all_Segmd01pp_MC_T = []
all_Segmd01cp_MC_T = []
all_Seggrippp_MC_T = []
all_Seggripcp_MC_T = []
all_Segepicpp_MC_T = []
all_Segepicpp1km_MC_T = []
all_Segepiccp_MC_T = []
all_Jouvet_MC_T = []

Segmd01pp_perc_MC_agree_T = []
Segmd01cp_perc_MC_agree_T = []
Seggrippp_perc_MC_agree_T = []
Seggripcp_perc_MC_agree_T = []
Segepicpp_perc_MC_agree_T = []
Segepicpp1km_perc_MC_agree_T = []
Segepiccp_perc_MC_agree_T = []
Jouvet_perc_MC_agree_T = []

Segmd01pp_perc_MC_disagree_T = []
Segmd01cp_perc_MC_disagree_T = []
Seggrippp_perc_MC_disagree_T = []
Seggripcp_perc_MC_disagree_T = []
Segepicpp_perc_MC_disagree_T = []
Segepicpp1km_perc_MC_disagree_T = []
Segepiccp_perc_MC_disagree_T = []
Jouvet_perc_MC_disagree_T = []


for g in range(0, MCs):
    #calculate sample size
    A = len(np.hstack([np.array(Segmd01pp_agree_MC_T[g]), np.array(Segmd01pp_disagree_MC_T[g])]))
    B = len(np.hstack([np.array(Segmd01cp_agree_MC_T[g]), np.array(Segmd01cp_disagree_MC_T[g])]))
    C = len(np.hstack([np.array(Seggrippp_agree_MC_T[g]), np.array(Seggrippp_disagree_MC_T[g])]))
    D = len(np.hstack([np.array(Seggripcp_agree_MC_T[g]), np.array(Seggripcp_disagree_MC_T[g])]))
    E = len(np.hstack([np.array(Segepicpp_agree_MC_T[g]), np.array(Segepicpp_disagree_MC_T[g])]))
    F = len(np.hstack([np.array(Segepiccp_agree_MC_T[g]), np.array(Segepiccp_disagree_MC_T[g])]))
    G = len(np.hstack([np.array(Jouvet_agree_MC_T[g]), np.array(Jouvet_disagree_MC_T[g])]))   
    H = len(np.hstack([np.array(Segepicpp1km_agree_MC_T[g]), np.array(Segepicpp1km_disagree_MC_T[g])]))
    
    all_Segmd01pp_MC_T.append(A)
    all_Segmd01cp_MC_T.append(B)
    all_Seggrippp_MC_T.append(C)
    all_Seggripcp_MC_T.append(D)
    all_Segepicpp_MC_T.append(E)
    all_Segepicpp1km_MC_T.append(H)
    all_Segepiccp_MC_T.append(F)   
    all_Jouvet_MC_T.append(G)   
    #calculate percentage in each group
    Segmd01pp_perc_MC_agree_T.append(len(Segmd01pp_agree_MC_T[g])/A*100)
    Segmd01cp_perc_MC_agree_T.append(len(Segmd01cp_agree_MC_T[g])/B*100)
    Seggrippp_perc_MC_agree_T.append(len(Seggrippp_agree_MC_T[g])/C*100)
    Seggripcp_perc_MC_agree_T.append(len(Seggripcp_agree_MC_T[g])/D*100)
    Segepicpp_perc_MC_agree_T.append(len(Segepicpp_agree_MC_T[g])/E*100)
    Segepicpp1km_perc_MC_agree_T.append(len(Segepicpp1km_agree_MC_T[g])/H*100)
    Segepiccp_perc_MC_agree_T.append(len(Segepiccp_agree_MC_T[g])/F*100)
    Jouvet_perc_MC_agree_T.append(len(Jouvet_agree_MC_T[g])/G*100)

    Segmd01pp_perc_MC_disagree_T.append(len(Segmd01pp_disagree_MC_T[g])/A*100)
    Segmd01cp_perc_MC_disagree_T.append(len(Segmd01cp_disagree_MC_T[g])/B*100)
    Seggrippp_perc_MC_disagree_T.append(len(Seggrippp_disagree_MC_T[g])/C*100)
    Seggripcp_perc_MC_disagree_T.append(len(Seggripcp_disagree_MC_T[g])/D*100)
    Segepicpp_perc_MC_disagree_T.append(len(Segepicpp_disagree_MC_T[g])/E*100)
    Segepicpp1km_perc_MC_disagree_T.append(len(Segepicpp1km_disagree_MC_T[g])/H*100)
    Segepiccp_perc_MC_disagree_T.append(len(Segepiccp_disagree_MC_T[g])/F*100)
    Jouvet_perc_MC_disagree_T.append(len(Jouvet_disagree_MC_T[g])/G*100)    

#mean and standard dev of percentage in each group
Segmd01pp_agree_mean_T = np.mean(Segmd01pp_perc_MC_agree_T)
Segmd01pp_disagree_mean_T = np.mean(Segmd01pp_perc_MC_disagree_T)
Segmd01cp_agree_mean_T = np.mean(Segmd01cp_perc_MC_agree_T)
Segmd01cp_disagree_mean_T = np.mean(Segmd01cp_perc_MC_disagree_T)
Seggrippp_agree_mean_T = np.mean(Seggrippp_perc_MC_agree_T)
Seggrippp_disagree_mean_T = np.mean(Seggrippp_perc_MC_disagree_T)
Seggripcp_agree_mean_T = np.mean(Seggripcp_perc_MC_agree_T)
Seggripcp_disagree_mean_T = np.mean(Seggripcp_perc_MC_disagree_T) 
Segepicpp_agree_mean_T = np.mean(Segepicpp_perc_MC_agree_T)
Segepicpp_disagree_mean_T = np.mean(Segepicpp_perc_MC_disagree_T)
Segepicpp1km_agree_mean_T = np.mean(Segepicpp1km_perc_MC_agree_T)
Segepicpp1km_disagree_mean_T = np.mean(Segepicpp1km_perc_MC_disagree_T)
Segepiccp_agree_mean_T = np.mean(Segepiccp_perc_MC_agree_T)
Segepiccp_disagree_mean_T = np.mean(Segepiccp_perc_MC_disagree_T) 
Jouvet_agree_mean_T = np.mean(Jouvet_perc_MC_agree_T)
Jouvet_disagree_mean_T = np.mean(Jouvet_perc_MC_disagree_T) 

Segmd01pp_agree_std_T = np.std(Segmd01pp_perc_MC_agree_T)
Segmd01pp_disagree_std_T = np.std(Segmd01pp_perc_MC_disagree_T)
Segmd01cp_agree_std_T = np.std(Segmd01cp_perc_MC_agree_T)
Segmd01cp_disagree_std_T = np.std(Segmd01cp_perc_MC_disagree_T)
Seggrippp_agree_std_T = np.std(Seggrippp_perc_MC_agree_T)
Seggrippp_disagree_std_T = np.std(Seggrippp_perc_MC_disagree_T)
Seggripcp_agree_std_T = np.std(Seggripcp_perc_MC_agree_T)
Seggripcp_disagree_std_T = np.std(Seggripcp_perc_MC_disagree_T) 
Segepicpp_agree_std_T = np.std(Segepicpp_perc_MC_agree_T)
Segepicpp_disagree_std_T = np.std(Segepicpp_perc_MC_disagree_T)
Segepicpp1km_agree_std_T = np.std(Segepicpp1km_perc_MC_agree_T)
Segepicpp1km_disagree_std_T = np.std(Segepicpp1km_perc_MC_disagree_T)
Segepiccp_agree_std_T = np.std(Segepiccp_perc_MC_agree_T)
Segepiccp_disagree_std_T = np.std(Segepiccp_perc_MC_disagree_T) 
Jouvet_agree_std_T = np.std(Jouvet_perc_MC_agree_T)
Jouvet_disagree_std_T = np.std(Jouvet_perc_MC_disagree_T) 




factor = 2 #set to 1 if only 1 sigma should be shown as error bar

colors =  plt.cm.tab20b( (4/2*np.arange(14*2/4)).astype(int) )
fig = plt.subplots(figsize=(10, 8.5))

#bar plot
# Set width of bars
barWidth = 0.1
space = 0.005
# Produce colour scheme 
clor = clrs.ListedColormap(['#1b9e77', '#7EF2C7','#d95f02', '#FFB05C', '#7570b3', '#ABA4EB', '#E3DBFF', '#282A65'])


# Set position of bar on X axis
r1 =  np.arange((2))
r2 = [x + barWidth + space for x in r1]
r3 = [x + barWidth + space for x in r2]
r4 = [x + barWidth + space for x in r3]
r5 = [x + barWidth + space for x in r4]
r6 = [x + barWidth + space for x in r5]
r7 = [x + barWidth + space for x in r6]
r8 = [x + barWidth + space for x in r7]

      
# Make the plot
plt.bar(r1, [Segmd01cp_agree_mean_T, Segmd01cp_disagree_mean_T], yerr=[factor*Segmd01cp_agree_std_T, factor*Segmd01cp_disagree_std_T], align='center', capsize=10, hatch='/', color=clor(0), width=barWidth, edgecolor='white', label='Seguinot et al., Ib. Margin, cp')
plt.bar(r2, [Segmd01pp_agree_mean_T, Segmd01pp_disagree_mean_T], yerr=[factor*Segmd01pp_agree_std_T, factor*Segmd01pp_disagree_std_T], align='center', capsize=10, hatch='/', color=clor(1), width=barWidth, edgecolor='white', label='Seguinot et al., Ib. Margin, pp')
plt.bar(r3, [Seggripcp_agree_mean_T, Seggripcp_disagree_mean_T], yerr=[factor*Seggripcp_agree_std_T, factor*Seggripcp_disagree_std_T], align='center', capsize=10, hatch='+', color=clor(2), width=barWidth, edgecolor='white', label='Seguinot et al., GRIP, cp')
plt.bar(r4, [Seggrippp_agree_mean_T, Seggrippp_disagree_mean_T], yerr=[factor*Seggrippp_agree_std_T, factor*Seggrippp_disagree_std_T], align='center', capsize=10, hatch='+', color=clor(3), width=barWidth, edgecolor='white', label='Seguinot et al., GRIP, pp')
plt.bar(r5, [Segepiccp_agree_mean_T, Segepiccp_disagree_mean_T], yerr=[factor*Segepiccp_agree_std_T, factor*Segepiccp_disagree_std_T], align='center', capsize=10, hatch='o', color=clor(4), width=barWidth, edgecolor='white', label='Seguinot et al., EPICA, cp')
plt.bar(r6, [Segepicpp_agree_mean_T, Segepicpp_disagree_mean_T], yerr=[factor*Segepicpp_agree_std_T, factor*Segepicpp_disagree_std_T], align='center', capsize=10, hatch='o', color=clor(5), width=barWidth, edgecolor='white', label='Seguinot et al., EPICA, pp')#
plt.bar(r7, [Segepicpp1km_agree_mean_T, Segepicpp1km_disagree_mean_T], yerr=[factor*Segepicpp1km_agree_std_T, factor*Segepicpp1km_disagree_std_T], align='center', capsize=10, hatch='o', color=clor(6), width=barWidth, edgecolor='white', label='Seguinot et al., EPICA, pp,\n1 km')#
plt.bar(r8, [Jouvet_agree_mean_T, Jouvet_disagree_mean_T], yerr=[factor*Jouvet_agree_std_T, factor*Jouvet_disagree_std_T], capsize=10, hatch='o', align='center', color=clor(7), width=barWidth, edgecolor='white', label='Jouvet et al., EPICA')


# Add xticks on the middle of the group bars

plt.xticks(r4, ['Warm-based glacier', 'Cold-based glacier'], fontsize=18)
plt.ylabel("Percentage of data points [%]", fontsize =18, weight="bold", labelpad=0.5)
plt.yticks(fontsize = 18)
plt.ylim(0,100)

# Create legend 
leg = plt.legend(prop={'size': 12}, loc="upper left", ncol=1)
leg.set_title('Simulation',prop={'size':16, 'weight':"bold"})
#plt.show()

plt.savefig("paper/NorthAlpsSpeleo_growthvsTatbase_20230606_newinterpnew_2groups_warmaboveminus2C_2ndthresh0dot5.png", dpi=350, bbox_inches = 'tight')

