# -*- coding: utf-8 -*-
"""
Created on Thu Nov 16 16:43:45 2023

@author: skiba
"""
###################import data###################
#Most speleothem data is publicly available and should be extracted from the SISALv2 database (https://researchdata.reading.ac.uk/256/) 
#Data from previously unpublished record obtained from stalagite M6_1_57 from Schratten cave, 
#Melchsee-Frutt cave system, Switzerland, can be found in the Supplementary material of the corresponding publication.
#For all other speleothem data please contact Christoph Spötl from the University of Innsbruck: christoph.spoetl@uibk.ac.at

#Alpine Ice Field simulation results are available on zenodo (https://zenodo.org/record/1423176 for Seguinot et al. (2018)
#and https://zenodo.org/records/8270674 for Jouvet et al. (2023), respectively. The simulations should be downloaded and placed 
#in the working directory.


import PySimpleGUI as sg
import xarray as xr 
import hyoga
import netCDF4
import scipy
import pandas as pd
import numpy as np
import matplotlib.pyplot as plt
import cartopy.crs as ccrs
import cartopy.feature as cfeature
import matplotlib as mpl
import scipy.stats as stats
import seaborn as sns
from matplotlib.patches import Rectangle
from mpl_toolkits.axes_grid1 import make_axes_locatable
from mpl_toolkits.mplot3d import Axes3D as ax
import matplotlib.ticker
from matplotlib.ticker import ScalarFormatter, FormatStrFormatter, StrMethodFormatter, MultipleLocator, AutoMinorLocator
from numpy import random
from matplotlib import cm
from matplotlib.colors import ListedColormap, LinearSegmentedColormap
import matplotlib.markers as mmarkers
from matplotlib.patches import Patch
from matplotlib.lines import Line2D
import matplotlib.lines as mlines
from netCDF4 import Dataset
from scipy import interpolate
from scipy.interpolate import RegularGridInterpolator , LinearNDInterpolator
from scipy.signal import butter, lfilter
import matplotlib.colors as clrs
from pyproj import Transformer
#import os
#os.chdir('C:\\')

def find_nearest(array, value):
    array = np.asarray(array)
    idx = np.nanargmin((np.abs(array - value)))
    return array[idx]

def find_nearestidx(array, value):
    array = np.asarray(array)
    idx = np.nanargmin((np.abs(array - value)))
    return idx

def find_2ndnearestidx(array, value):
    array = np.asarray(array)
    idx = np.argsort(np.abs(array-value))[1]#np.nanargmin((np.abs(array - value)))
    return idx

def find_2ndnearest(array, value):
    array = np.asarray(array)
    idx = np.argsort(np.abs(array-value))[1]#np.nanargmin((np.abs(array - value)))
    return array[idx]

def setdiff_sorted(array1,array2,assume_unique=False):
    ans = np.setdiff1d(array1,array2,assume_unique).tolist()
    if assume_unique:
        return sorted(ans)
    return ans


####################prepare array with data from all cave sites###################
##(if more then one record per cave site exists, this will be an array where all data is stacked)##
#e.g.
#Schratten_d13C_all = np.hstack([array1_d13C, array2_d13C])
#Schratten_sampleages = np.hstack([array1_ages, array2_ages])

####################prepare speleo d13C list including all sites###################
sampleages = [Spannagel_sampleages, Baschg_sampleages, SHengste_sampleages, Schafsloch_sampleages, (TKS[:,1]/1000), Hoelloch_sampleages, Schneckenloch_sampleages, HUN_14[:,0]/1000, Gassel_sampleages, Schratten_sampleages, Neo_sampleages, KlausCramer_sampleages, Beatus_sampleages]
d13C_all = [Spannagel_d13C_all, Baschg_d13C_all, SHengste_d13C_all, Schafsloch_d13C_all, TKS[:,2], Hoelloch_d13C_all, Schneckenloch_d13C_all, HUN_14[:,2], Gassel_d13C_all, Schratten_d13C_all, Neo_d13C_all, KlausCramer_d13C_all, Beatus_d13C_all] 
   

cavelats_entities = [47.08, 47.25, 46.75, 47.28, 47.38, 47.33, 47.54, 47.82, 46.78, 47.36, 46.69]
cavelongs_entities = [11.67, 9.67, 7.81, 13.08, 10.15, 9.87, 12.03, 13.84, 8.27, 10.11, 7.78]
cavenames_entities = ["Spannagel", "Baschg", "Sieben Hengste",  "Entrische Kirche", 
                      "Hölloch im Mahdtal", "Schneckenloch", "Grete-Ruth shaft", "Gassel", "Schratten", 
                       'Klaus-Cramer', 'Beatus']
elevation = [2512, 870, 1883, 1040, 1560, 1568, 1491, 1196, 1862,  1964, 1080] 
markerrr = ["*", "v", "^", "<",">","o","d","X","D", "p", "H"]

###
###################cave site d13C vs. modelled glacier agreement over time###################
####

Spannagel_disagreement_x = []
Spannagel_disagreement_age_x = []
Baschg_disagreement_x = []
Baschg_disagreement_age_x = []
SiebenHengste_disagreement_x = []
SiebenHengste_disagreement_age_x = []
Entrische_disagreement_x = []
Entrische_disagreement_age_x = []
Hoelloch_disagreement_x = []
Hoelloch_disagreement_age_x = []
Schneckenloch_disagreement_x = []
Schneckenloch_disagreement_age_x = []
Grete_disagreement_x = []
Grete_disagreement_age_x = []
Gassel_disagreement_x = []
Gassel_disagreement_age_x = []
Schratten_disagreement_x = []
Schratten_disagreement_age_x = []
Neotektonik_disagreement_x = []
Neotektonik_disagreement_age_x = []
Klaus_disagreement_x = []
Klaus_disagreement_age_x = []
Beatus_disagreement_x = []
Beatus_disagreement_age_x = []


Spannagel_agreement_version_x = []
Spannagel_agreement_version_age_x = []
Baschg_agreement_version_x = []
Baschg_agreement_version_age_x = []
SiebenHengste_agreement_version_x = []
SiebenHengste_agreement_version_age_x = []
Entrische_agreement_version_x = []
Entrische_agreement_version_age_x = []
Hoelloch_agreement_version_x = []
Hoelloch_agreement_version_age_x = []
Schneckenloch_agreement_version_x = []
Schneckenloch_agreement_version_age_x = []
Grete_agreement_version_x = []
Grete_agreement_version_age_x = []
Gassel_agreement_version_x = []
Gassel_agreement_version_age_x = []
Schratten_agreement_version_x = []
Schratten_agreement_version_age_x = []
Neotektonik_agreement_version_x = []
Neotektonik_agreement_version_age_x = []
Klaus_agreement_version_x = []
Klaus_agreement_version_age_x = []
Beatus_agreement_version_x = []
Beatus_agreement_version_age_x = []

disagreement = []
disagreement_age = []
agreement = []
agreement_age = []

agg_x = []
agg = []


sampling_step = 6#4#2#4#6#4#2
window_size = sampling_step#6#2
start = 12
end = 114

bins_start = np.arange(start, end, sampling_step)
bins_end =  np.arange(start+window_size, end+window_size, sampling_step)

glacthick = 20

simus = ['alpcyc.2km.md01.cp.ex.1ka.nc', 'alpcyc.2km.md01.pp.ex.1ka.nc', 
                    'alpcyc.2km.grip.cp.ex.1ka.nc', 
                    'alpcyc.2km.grip.pp.ex.1ka.nc', 
                    'alpcyc.2km.epic.cp.ex.1ka.nc', 'alpcyc.2km.epic.pp.ex.1ka.nc', 'alpcyc.1km.epic.pp.ex.1ka.nc', 
                    'ex-AIF-paper.nc']

simus_names = [["Seguinot et al. Iberian Margin, cp"], ["Seguinot et al. Iberian Margin, pp"], ["Seguinot et al. GRIP, cp"], ["Seguinot et al. GRIP, pp"], ["Seguinot et al. EPICA, cp"], ["Seguinot et al. EPICA, pp"], ["Seguinot et al. EPICA, pp, 1 km"], ["Jouvet et al. EPICA"]]


for o in range(0, len(simus)):
    ds = hyoga.open.dataset(simus[o])
    nc    = Dataset(simus[o], 'r') 
    time2 = np.squeeze(nc.variables['time'][:])
    time = np.round((time2 / 31536000)/1000, 2) 
    x      = np.squeeze(nc.variables['x'])
    y      = np.squeeze(nc.variables['y'])
    topg = np.squeeze(nc.variables['topg'])            
    thk2 = np.squeeze(nc.variables['thk'])
    thk = np.select([thk2 == -2000000000.0], [0], thk2) 

    nc.close()
    TOP = RegularGridInterpolator((time, y, x), topg, bounds_error=False, fill_value=None, method="linear")#, method="linear")
    THK = RegularGridInterpolator((time, y, x), thk, bounds_error=False, fill_value=None)

    
    Spannagel_disagreement = []
    Spannagel_disagreement_age = []
    Baschg_disagreement = []
    Baschg_disagreement_age = []
    SiebenHengste_disagreement = []
    SiebenHengste_disagreement_age = []
    Entrische_disagreement = []
    Entrische_disagreement_age = []
    Hoelloch_disagreement = []
    Hoelloch_disagreement_age = []
    Schneckenloch_disagreement = []
    Schneckenloch_disagreement_age = []
    Grete_disagreement = []
    Grete_disagreement_age = []
    Gassel_disagreement = []
    Gassel_disagreement_age = []
    Schratten_disagreement = []
    Schratten_disagreement_age = []
    Neotektonik_disagreement = []
    Neotektonik_disagreement_age = []
    Klaus_disagreement = []
    Klaus_disagreement_age = []
    Beatus_disagreement = []
    Beatus_disagreement_age = []
    
    
    Spannagel_agreement_version = []
    Spannagel_agreement_version_age = []
    Baschg_agreement_version = []
    Baschg_agreement_version_age = []
    SiebenHengste_agreement_version = []
    SiebenHengste_agreement_version_age = []
    Entrische_agreement_version = []
    Entrische_agreement_version_age = []
    Hoelloch_agreement_version = []
    Hoelloch_agreement_version_age = []
    Schneckenloch_agreement_version = []
    Schneckenloch_agreement_version_age = []
    Grete_agreement_version = []
    Grete_agreement_version_age = []
    Gassel_agreement_version = []
    Gassel_agreement_version_age = []
    Schratten_agreement_version = []
    Schratten_agreement_version_age = []
    Neotektonik_agreement_version = []
    Neotektonik_agreement_version_age = []
    Klaus_agreement_version = []
    Klaus_agreement_version_age = []
    Beatus_agreement_version = []
    Beatus_agreement_version_age = []
    
    icethk_alltimepoints = []
    d13C_alltimepoints = []
    age_alltimepoints = []
    elev = []
    marker = []
    elevation_alltimepoints = []
    long_alltimepoints = []
    cave_alltimepoints = []
    
    
    Spannagel_age_alltimepoints = []
    Spannagel_d13C_alltimepoints = []
    Spannagel_icethk_alltimepoints = []
    Spannagel_agreementratio = []
    Spannagel_agreementratio_age = []
    
    Baschg_age_alltimepoints = []
    Baschg_d13C_alltimepoints = []
    Baschg_icethk_alltimepoints = []
    Baschg_agreementratio = []
    Baschg_agreementratio_age = []
    
    SiebenHengste_age_alltimepoints = []
    SiebenHengste_d13C_alltimepoints = []
    SiebenHengste_icethk_alltimepoints = []
    SiebenHengste_agreementratio = []
    SiebenHengste_agreementratio_age = []
    
    Entrische_age_alltimepoints = []
    Entrische_d13C_alltimepoints = []
    Entrische_icethk_alltimepoints = []
    Entrische_agreementratio = []
    Entrische_agreementratio_age = []
    
    Hoelloch_age_alltimepoints = []
    Hoelloch_d13C_alltimepoints = []
    Hoelloch_icethk_alltimepoints = []
    Hoelloch_agreementratio = []
    Hoelloch_agreementratio_age = []
    
    Schneckenloch_age_alltimepoints = []
    Schneckenloch_d13C_alltimepoints = []
    Schneckenloch_icethk_alltimepoints = []
    Schneckenloch_agreementratio = []
    Schneckenloch_agreementratio_age = []
    
    Grete_age_alltimepoints = []
    Grete_d13C_alltimepoints = []
    Grete_icethk_alltimepoints = []
    Grete_agreementratio = []
    Grete_agreementratio_age = []
    
    Gassel_age_alltimepoints = []
    Gassel_d13C_alltimepoints = []
    Gassel_icethk_alltimepoints = []
    Gassel_agreementratio = []
    Gassel_agreementratio_age = []
    
    Schratten_age_alltimepoints = []
    Schratten_d13C_alltimepoints = []
    Schratten_icethk_alltimepoints = []
    Schratten_agreementratio = []
    Schratten_agreementratio_age = []
    
    Neotektonik_age_alltimepoints = []
    Neotektonik_d13C_alltimepoints = []
    Neotektonik_icethk_alltimepoints = []
    Neotektonik_agreementratio = []
    Neotektonik_agreementratio_age = []
    
    Klaus_age_alltimepoints = []
    Klaus_d13C_alltimepoints = []
    Klaus_icethk_alltimepoints = []
    Klaus_agreementratio = []
    Klaus_agreementratio_age = []
    
    Beatus_age_alltimepoints = []
    Beatus_d13C_alltimepoints = []
    Beatus_icethk_alltimepoints = []
    Beatus_agreementratio = []
    Beatus_agreementratio_age = []
    
    Spannagel_agreement_1 = []
    Spannagel_agreement_1_age = []
    Spannagel_agreement_2 = []
    Spannagel_agreement_2_age = []
    Spannagel_agreement_3 = []
    Spannagel_agreement_3_age = []
       
    Baschg_agreement_1 = []
    Baschg_agreement_1_age = []
    Baschg_agreement_2 = []
    Baschg_agreement_2_age = []
    Baschg_agreement_3 = []
    Baschg_agreement_3_age = []
    
    SiebenHengste_agreement_1 = []
    SiebenHengste_agreement_1_age = []
    SiebenHengste_agreement_2 = []
    SiebenHengste_agreement_2_age = []
    SiebenHengste_agreement_3 = []
    SiebenHengste_agreement_3_age = []
    
    Entrische_agreement_1 = []
    Entrische_agreement_1_age = []
    Entrische_agreement_2 = []
    Entrische_agreement_2_age = []
    Entrische_agreement_3 = []
    Entrische_agreement_3_age = []          
    
    Hoelloch_agreement_1 = []
    Hoelloch_agreement_1_age = []
    Hoelloch_agreement_2 = []
    Hoelloch_agreement_2_age = []
    Hoelloch_agreement_3 = []
    Hoelloch_agreement_3_age = []          
    
    Schneckenloch_agreement_1 = []
    Schneckenloch_agreement_1_age = []
    Schneckenloch_agreement_2 = []
    Schneckenloch_agreement_2_age = []
    Schneckenloch_agreement_3 = []
    Schneckenloch_agreement_3_age = []          
    
    Grete_agreement_1 = []
    Grete_agreement_1_age = []
    Grete_agreement_2 = []
    Grete_agreement_2_age = []
    Grete_agreement_3 = []
    Grete_agreement_3_age = []          
    
    Gassel_agreement_1 = []
    Gassel_agreement_1_age = []
    Gassel_agreement_2 = []
    Gassel_agreement_2_age = []
    Gassel_agreement_3 = []
    Gassel_agreement_3_age = []          
    
    Schratten_agreement_1 = []
    Schratten_agreement_1_age = []
    Schratten_agreement_2 = []
    Schratten_agreement_2_age = []
    Schratten_agreement_3 = []
    Schratten_agreement_3_age = []          
    
    Neotektonik_agreement_1 = []
    Neotektonik_agreement_1_age = []
    Neotektonik_agreement_2 = []
    Neotektonik_agreement_2_age = []
    Neotektonik_agreement_3 = []
    Neotektonik_agreement_3_age = []          
    
    Klaus_agreement_1 = []
    Klaus_agreement_1_age = []
    Klaus_agreement_2 = []
    Klaus_agreement_2_age = []
    Klaus_agreement_3 = []
    Klaus_agreement_3_age = []          
    
    Beatus_agreement_1 = []
    Beatus_agreement_1_age = []
    Beatus_agreement_2 = []
    Beatus_agreement_2_age = []
    Beatus_agreement_3 = []
    Beatus_agreement_3_age = []          

    
    for g in range(0, len(cavelats_entities)):
        ax = plt.subplot(projection=ccrs.UTM(32))
        [handle] = ax.plot(cavelongs_entities[g], cavelats_entities[g], marker='*', color='black', markersize=6, transform=ccrs.Geodetic())
        t_path = handle._get_transformed_path()
        path_in_data_coords, _ = t_path.get_transformed_path_and_affine()
        print(path_in_data_coords.vertices) 
        Xval = path_in_data_coords.vertices[0][0]
        Yval = path_in_data_coords.vertices[0][1]
        f = g 
        for u in range(0,len(sampleages[f])):
            if sampleages[f][u] > 12 and sampleages[f][u] < 115: 
                pts = (-sampleages[f][u], Yval, Xval)

                thkkk = THK(pts)
                if cavenames_entities[f] == 'Spannagel':
                   Spannagel_age_alltimepoints.append(sampleages[f][u])                
                   Spannagel_d13C_alltimepoints.append(d13C_all[f][u])
                   Spannagel_icethk_alltimepoints.append(thkkk)
                if cavenames_entities[f] == 'Baschg':
                   Baschg_age_alltimepoints.append(sampleages[f][u])
                   Baschg_d13C_alltimepoints.append(d13C_all[f][u])
                   Baschg_icethk_alltimepoints.append(thkkk)
                if cavenames_entities[f] == 'Sieben Hengste':
                   SiebenHengste_age_alltimepoints.append(sampleages[f][u])
                   SiebenHengste_d13C_alltimepoints.append(d13C_all[f][u])
                   SiebenHengste_icethk_alltimepoints.append(thkkk)
                if cavenames_entities[f] == 'Entrische Kirche':
                   Entrische_age_alltimepoints.append(sampleages[f][u])
                   Entrische_d13C_alltimepoints.append(d13C_all[f][u])
                   Entrische_icethk_alltimepoints.append(thkkk)
                if cavenames_entities[f] == 'Hoelloch im Mahdtal':
                   Hoelloch_age_alltimepoints.append(sampleages[f][u])
                   Hoelloch_d13C_alltimepoints.append(d13C_all[f][u])
                   Hoelloch_icethk_alltimepoints.append(thkkk)
                if cavenames_entities[f] == 'Schneckenloch':
                   Schneckenloch_age_alltimepoints.append(sampleages[f][u])
                   Schneckenloch_d13C_alltimepoints.append(d13C_all[f][u])
                   Schneckenloch_icethk_alltimepoints.append(thkkk)
                if cavenames_entities[f] == 'Grete-Ruth shaft':
                   Grete_age_alltimepoints.append(sampleages[f][u])
                   Grete_d13C_alltimepoints.append(d13C_all[f][u])
                   Grete_icethk_alltimepoints.append(thkkk)
                if cavenames_entities[f] == 'Gassel':
                   Gassel_age_alltimepoints.append(sampleages[f][u])
                   Gassel_d13C_alltimepoints.append(d13C_all[f][u])
                   Gassel_icethk_alltimepoints.append(thkkk)
                if cavenames_entities[f] == 'Schratten':
                   Schratten_age_alltimepoints.append(sampleages[f][u])
                   Schratten_d13C_alltimepoints.append(d13C_all[f][u])
                   Schratten_icethk_alltimepoints.append(thkkk)
                if cavenames_entities[f] == 'Neotektonik':
                   Neotektonik_age_alltimepoints.append(sampleages[f][u])
                   Neotektonik_d13C_alltimepoints.append(d13C_all[f][u])
                   Neotektonik_icethk_alltimepoints.append(thkkk)
                if cavenames_entities[f] == 'Klaus-Cramer':
                   Klaus_age_alltimepoints.append(sampleages[f][u])
                   Klaus_d13C_alltimepoints.append(d13C_all[f][u])
                   Klaus_icethk_alltimepoints.append(thkkk)
                if cavenames_entities[f] == 'Beatus':
                   Beatus_age_alltimepoints.append(sampleages[f][u])
                   Beatus_d13C_alltimepoints.append(d13C_all[f][u])
                   Beatus_icethk_alltimepoints.append(thkkk)
                                                                                                                                                                                                          
        if cavenames_entities[f] == 'Spannagel':        
            Spannageldisagree_indi_y = []            
            Spannageldisagree_indi = []
            Spannagelagree_indi_y = []            
            Spannagelagree_indi = []
            Spannagelagree_1 = []
            Spannagelagree_1_y = []
            Spannagelagree_2 = []
            Spannagelagree_2_y = []
            Spannagelagree_3 = []
            Spannagelagree_3_y = []        
            for x in range(0,len(Spannagel_d13C_alltimepoints)):
               if Spannagel_d13C_alltimepoints[x] < -1 and Spannagel_icethk_alltimepoints[x] > glacthick:
                  Spannageldisagree_indi.append(Spannagel_age_alltimepoints[x])
                  Spannageldisagree_indi_y.append(-1)
                  
               elif Spannagel_d13C_alltimepoints[x] < -1 and Spannagel_icethk_alltimepoints[x] <= glacthick: 
                   Spannagelagree_1.append(Spannagel_age_alltimepoints[x])
                   Spannagelagree_1_y.append(1)
               elif Spannagel_d13C_alltimepoints[x] > -1 and Spannagel_icethk_alltimepoints[x] > glacthick: 
                   Spannagelagree_2.append(Spannagel_age_alltimepoints[x])
                   Spannagelagree_2_y.append(2)
               elif Spannagel_d13C_alltimepoints[x] > -1 and Spannagel_icethk_alltimepoints[x] <= glacthick: 
                   Spannagelagree_3.append(Spannagel_age_alltimepoints[x])
                   Spannagelagree_3_y.append(3)
                   
               if Spannagel_d13C_alltimepoints[x] > -1 or Spannagel_icethk_alltimepoints[x] <= glacthick:
                  Spannagelagree_indi.append(Spannagel_age_alltimepoints[x])
                  Spannagelagree_indi_y.append(1)
                    
            for u in range(0,len(bins_start)):
               a = np.array(Spannageldisagree_indi)[np.where((Spannageldisagree_indi > bins_start[u]) & (Spannageldisagree_indi <= bins_end[u]))]
               b = np.array(Spannagelagree_indi)[np.where((Spannagelagree_indi > bins_start[u]) & (Spannagelagree_indi <= bins_end[u]))]
               if len(a) == 0 and len(b) == 0:
                   pass
               elif len(a) == 0:
                   Spannagel_agreementratio.append(1)
                   Spannagel_agreementratio_age.append(bins_start[u]+(sampling_step/2))
               elif len(b) == 0 or len(a) > 0:
                   Spannagel_agreementratio.append(0)
                   Spannagel_agreementratio_age.append(bins_start[u]+(sampling_step/2))
               else:
                   Spannagel_agreementratio.append(len(a)/len(b))
                   Spannagel_agreementratio_age.append(bins_start[u]+(sampling_step/2))
               if len(a) > 0:
                   Spannagel_disagreement.append(0)
                   Spannagel_disagreement_age.append(bins_start[u]+(sampling_step/2))
                   
               elif len(np.array(Spannagelagree_1)[np.where((Spannagelagree_1 > bins_start[u]) & (Spannagelagree_1 <= bins_end[u]))]) != 0 or len(np.array(Spannagelagree_2)[np.where((Spannagelagree_2 > bins_start[u]) & (Spannagelagree_2 <= bins_end[u]))]) != 0 or len(np.array(Spannagelagree_3)[np.where((Spannagelagree_3 > bins_start[u]) & (Spannagelagree_3 <= bins_end[u]))]) != 0:
                      Spannagel_agreement_version.append(np.argmax([len(np.array(Spannagelagree_1)[np.where((Spannagelagree_1 > bins_start[u]) & (Spannagelagree_1 <= bins_end[u]))]), len(np.array(Spannagelagree_2)[np.where((Spannagelagree_2 > bins_start[u]) & (Spannagelagree_2 <= bins_end[u]))]), len(np.array(Spannagelagree_3)[np.where((Spannagelagree_3 > bins_start[u]) & (Spannagelagree_3 <= bins_end[u]))])]) + 1)
                      Spannagel_agreement_version_age.append(bins_start[u]+(sampling_step/2))  

        
        if cavenames_entities[f] == 'Baschg':        
           Baschgdisagree_indi_y = []            
           Baschgdisagree_indi = []
           Baschgagree_indi_y = []            
           Baschgagree_indi = []
           Baschgagree_1 = []
           Baschgagree_1_y = []
           Baschgagree_2 = []
           Baschgagree_2_y = []
           Baschgagree_3 = []
           Baschgagree_3_y = []        
           for x in range(0,len(Baschg_d13C_alltimepoints)):
              if Baschg_d13C_alltimepoints[x] < -1 and Baschg_icethk_alltimepoints[x] > glacthick:
                 Baschgdisagree_indi.append(Baschg_age_alltimepoints[x])
                 Baschgdisagree_indi_y.append(-1)
                 
              elif Baschg_d13C_alltimepoints[x] < -1 and Baschg_icethk_alltimepoints[x] <= glacthick: 
                   Baschgagree_1.append(Baschg_age_alltimepoints[x])
                   Baschgagree_1_y.append(1)
              elif Baschg_d13C_alltimepoints[x] > -1 and Baschg_icethk_alltimepoints[x] > glacthick: 
                   Baschgagree_2.append(Baschg_age_alltimepoints[x])
                   Baschgagree_2_y.append(2)
              elif Baschg_d13C_alltimepoints[x] > -1 and Baschg_icethk_alltimepoints[x] <= glacthick: 
                   Baschgagree_3.append(Baschg_age_alltimepoints[x])
                   Baschgagree_3_y.append(3)
                 
              if Baschg_d13C_alltimepoints[x] > -1 or Baschg_icethk_alltimepoints[x] <= glacthick:
                 Baschgagree_indi.append(Baschg_age_alltimepoints[x])
                 Baschgagree_indi_y.append(1)
                    
           for u in range(0,len(bins_start)):
               a = np.array(Baschgdisagree_indi)[np.where((Baschgdisagree_indi > bins_start[u]) & (Baschgdisagree_indi <= bins_end[u]))]
               b = np.array(Baschgagree_indi)[np.where((Baschgagree_indi > bins_start[u]) & (Baschgagree_indi <= bins_end[u]))]
               if len(a) == 0 and len(b) == 0:
                   pass
               elif len(a) == 0:
                   Baschg_agreementratio.append(1)
                   Baschg_agreementratio_age.append(bins_start[u]+(sampling_step/2))
               elif len(b) == 0 or len(a) > 0:
                   Baschg_agreementratio.append(0)
                   Baschg_agreementratio_age.append(bins_start[u]+(sampling_step/2)),
               else:
                   Baschg_agreementratio.append(len(a)/len(b))
                   Baschg_agreementratio_age.append(bins_start[u]+(sampling_step/2))#
               if len(a) > 0:
                   Baschg_disagreement.append(0)
                   Baschg_disagreement_age.append(bins_start[u]+(sampling_step/2))
                   
               elif len(np.array(Baschgagree_1)[np.where((Baschgagree_1 > bins_start[u]) & (Baschgagree_1 <= bins_end[u]))]) != 0 or len(np.array(Baschgagree_2)[np.where((Baschgagree_2 > bins_start[u]) & (Baschgagree_2 <= bins_end[u]))]) != 0 or len(np.array(Baschgagree_3)[np.where((Baschgagree_3 > bins_start[u]) & (Baschgagree_3 <= bins_end[u]))]) != 0:
                      Baschg_agreement_version.append(np.argmax([len(np.array(Baschgagree_1)[np.where((Baschgagree_1 > bins_start[u]) & (Baschgagree_1 <= bins_end[u]))]), len(np.array(Baschgagree_2)[np.where((Baschgagree_2 > bins_start[u]) & (Baschgagree_2 <= bins_end[u]))]), len(np.array(Baschgagree_3)[np.where((Baschgagree_3 > bins_start[u]) & (Baschgagree_3 <= bins_end[u]))])]) + 1)
                      Baschg_agreement_version_age.append(bins_start[u]+(sampling_step/2))  

        if cavenames_entities[f] == 'Sieben Hengste':        
           SiebenHengstedisagree_indi_y = []            
           SiebenHengstedisagree_indi = []
           SiebenHengsteagree_indi_y = []            
           SiebenHengsteagree_indi = []
           SiebenHengsteagree_1 = []
           SiebenHengsteagree_1_y = []
           SiebenHengsteagree_2 = []
           SiebenHengsteagree_2_y = []
           SiebenHengsteagree_3 = []
           SiebenHengsteagree_3_y = []   
           for x in range(0,len(SiebenHengste_d13C_alltimepoints)):
              if SiebenHengste_d13C_alltimepoints[x] < -1 and SiebenHengste_icethk_alltimepoints[x] > glacthick:
                 SiebenHengstedisagree_indi.append(SiebenHengste_age_alltimepoints[x])
                 SiebenHengstedisagree_indi_y.append(-1)
              
              elif SiebenHengste_d13C_alltimepoints[x] < -1 and SiebenHengste_icethk_alltimepoints[x] <= glacthick: 
                   SiebenHengsteagree_1.append(SiebenHengste_age_alltimepoints[x])
                   SiebenHengsteagree_1_y.append(1)
              elif SiebenHengste_d13C_alltimepoints[x] > -1 and SiebenHengste_icethk_alltimepoints[x] > glacthick: 
                   SiebenHengsteagree_2.append(SiebenHengste_age_alltimepoints[x])
                   SiebenHengsteagree_2_y.append(2)
              elif SiebenHengste_d13C_alltimepoints[x] > -1 and SiebenHengste_icethk_alltimepoints[x] <= glacthick: 
                   SiebenHengsteagree_3.append(SiebenHengste_age_alltimepoints[x])
                   SiebenHengsteagree_3_y.append(3) 
                 
              if SiebenHengste_d13C_alltimepoints[x] > -1 or SiebenHengste_icethk_alltimepoints[x] <= glacthick:
                 SiebenHengsteagree_indi.append(SiebenHengste_age_alltimepoints[x])
                 SiebenHengsteagree_indi_y.append(1)
                    
           for u in range(0,len(bins_start)):
               a = np.array(SiebenHengstedisagree_indi)[np.where((SiebenHengstedisagree_indi > bins_start[u]) & (SiebenHengstedisagree_indi <= bins_end[u]))]
               b = np.array(SiebenHengsteagree_indi)[np.where((SiebenHengsteagree_indi > bins_start[u]) & (SiebenHengsteagree_indi <= bins_end[u]))]
               if len(a) == 0 and len(b) == 0:
                   pass
               elif len(a) == 0:
                   SiebenHengste_agreementratio.append(1)
                   SiebenHengste_agreementratio_age.append(bins_start[u]+(sampling_step/2))
               elif len(b) == 0 or len(a) > 0:
                   SiebenHengste_agreementratio.append(0)
                   SiebenHengste_agreementratio_age.append(bins_start[u]+(sampling_step/2)),
               else:
                   SiebenHengste_agreementratio.append(len(a)/len(b))
                   SiebenHengste_agreementratio_age.append(bins_start[u]+(sampling_step/2))
               if len(a) > 0:
                   SiebenHengste_disagreement.append(0)
                   SiebenHengste_disagreement_age.append(bins_start[u]+(sampling_step/2))
                   
               elif len(np.array(SiebenHengsteagree_1)[np.where((SiebenHengsteagree_1 > bins_start[u]) & (SiebenHengsteagree_1 <= bins_end[u]))]) != 0 or len(np.array(SiebenHengsteagree_2)[np.where((SiebenHengsteagree_2 > bins_start[u]) & (SiebenHengsteagree_2 <= bins_end[u]))]) != 0 or len(np.array(SiebenHengsteagree_3)[np.where((SiebenHengsteagree_3 > bins_start[u]) & (SiebenHengsteagree_3 <= bins_end[u]))]) != 0:
                      SiebenHengste_agreement_version.append(np.argmax([len(np.array(SiebenHengsteagree_1)[np.where((SiebenHengsteagree_1 > bins_start[u]) & (SiebenHengsteagree_1 <= bins_end[u]))]), len(np.array(SiebenHengsteagree_2)[np.where((SiebenHengsteagree_2 > bins_start[u]) & (SiebenHengsteagree_2 <= bins_end[u]))]), len(np.array(SiebenHengsteagree_3)[np.where((SiebenHengsteagree_3 > bins_start[u]) & (SiebenHengsteagree_3 <= bins_end[u]))])]) + 1)
                      SiebenHengste_agreement_version_age.append(bins_start[u]+(sampling_step/2))  

        if cavenames_entities[f] == 'Entrische Kirche':        
           Entrischedisagree_indi_y = []            
           Entrischedisagree_indi = []
           Entrischeagree_indi_y = []            
           Entrischeagree_indi = [] 
           Entrischeagree_1 = []
           Entrischeagree_1_y = []
           Entrischeagree_2 = []
           Entrischeagree_2_y = []
           Entrischeagree_3 = []
           Entrischeagree_3_y = []   
           for x in range(0,len(Entrische_d13C_alltimepoints)):
              if Entrische_d13C_alltimepoints[x] < -1 and Entrische_icethk_alltimepoints[x] > glacthick:
                 Entrischedisagree_indi.append(Entrische_age_alltimepoints[x])
                 Entrischedisagree_indi_y.append(-1)
                 
              elif Entrische_d13C_alltimepoints[x] < -1 and Entrische_icethk_alltimepoints[x] <= glacthick: 
                   Entrischeagree_1.append(Entrische_age_alltimepoints[x])
                   Entrischeagree_1_y.append(1)
              elif Entrische_d13C_alltimepoints[x] > -1 and Entrische_icethk_alltimepoints[x] > glacthick: 
                   Entrischeagree_2.append(Entrische_age_alltimepoints[x])
                   Entrischeagree_2_y.append(2)
              elif Entrische_d13C_alltimepoints[x] > -1 and Entrische_icethk_alltimepoints[x] <= glacthick: 
                   Entrischeagree_3.append(Entrische_age_alltimepoints[x])
                   Entrischeagree_3_y.append(3) 
                 
              if Entrische_d13C_alltimepoints[x] > -1 or Entrische_icethk_alltimepoints[x] <= glacthick:
                 Entrischeagree_indi.append(Entrische_age_alltimepoints[x])
                 Entrischeagree_indi_y.append(1)
                    
           for u in range(0,len(bins_start)):
               a = np.array(Entrischedisagree_indi)[np.where((Entrischedisagree_indi > bins_start[u]) & (Entrischedisagree_indi <= bins_end[u]))]
               b = np.array(Entrischeagree_indi)[np.where((Entrischeagree_indi > bins_start[u]) & (Entrischeagree_indi <= bins_end[u]))]
               if len(a) == 0 and len(b) == 0:
                   pass
               elif len(a) == 0:
                   Entrische_agreementratio.append(1)
                   Entrische_agreementratio_age.append(bins_start[u]+(sampling_step/2))
               elif len(b) == 0 or len(a) > 0:
                   Entrische_agreementratio.append(0)
                   Entrische_agreementratio_age.append(bins_start[u]+(sampling_step/2)),
               else:
                   Entrische_agreementratio.append(len(a)/len(b))
                   Entrische_agreementratio_age.append(bins_start[u]+(sampling_step/2))
               if len(a) > 0:
                   Entrische_disagreement.append(0)
                   Entrische_disagreement_age.append(bins_start[u]+(sampling_step/2))  
                   
               elif len(np.array(Entrischeagree_1)[np.where((Entrischeagree_1 > bins_start[u]) & (Entrischeagree_1 <= bins_end[u]))]) != 0 or len(np.array(Entrischeagree_2)[np.where((Entrischeagree_2 > bins_start[u]) & (Entrischeagree_2 <= bins_end[u]))]) != 0 or len(np.array(Entrischeagree_3)[np.where((Entrischeagree_3 > bins_start[u]) & (Entrischeagree_3 <= bins_end[u]))]) != 0:
                      Entrische_agreement_version.append(np.argmax([len(np.array(Entrischeagree_1)[np.where((Entrischeagree_1 > bins_start[u]) & (Entrischeagree_1 <= bins_end[u]))]), len(np.array(Entrischeagree_2)[np.where((Entrischeagree_2 > bins_start[u]) & (Entrischeagree_2 <= bins_end[u]))]), len(np.array(Entrischeagree_3)[np.where((Entrischeagree_3 > bins_start[u]) & (Entrischeagree_3 <= bins_end[u]))])]) + 1)
                      Entrische_agreement_version_age.append(bins_start[u]+(sampling_step/2))  

        if cavenames_entities[f] == 'Hoelloch im Mahdtal':        
           Hoellochdisagree_indi_y = []            
           Hoellochdisagree_indi = []
           Hoellochagree_indi_y = []            
           Hoellochagree_indi = []
           Hoellochagree_1 = []
           Hoellochagree_1_y = []
           Hoellochagree_2 = []
           Hoellochagree_2_y = []
           Hoellochagree_3 = []
           Hoellochagree_3_y = [] 
           for x in range(0,len(Hoelloch_d13C_alltimepoints)):
              if Hoelloch_d13C_alltimepoints[x] < -1 and Hoelloch_icethk_alltimepoints[x] > glacthick:
                 Hoellochdisagree_indi.append(Hoelloch_age_alltimepoints[x])
                 Hoellochdisagree_indi_y.append(-1)
                 
              elif Hoelloch_d13C_alltimepoints[x] < -1 and Hoelloch_icethk_alltimepoints[x] <= glacthick: 
                   Hoellochagree_1.append(Hoelloch_age_alltimepoints[x])
                   Hoellochagree_1_y.append(1)
              elif Hoelloch_d13C_alltimepoints[x] > -1 and Hoelloch_icethk_alltimepoints[x] > glacthick: 
                   Hoellochagree_2.append(Hoelloch_age_alltimepoints[x])
                   Hoellochagree_2_y.append(2)
              elif Hoelloch_d13C_alltimepoints[x] > -1 and Hoelloch_icethk_alltimepoints[x] <= glacthick: 
                   Hoellochagree_3.append(Hoelloch_age_alltimepoints[x])
                   Hoellochagree_3_y.append(3) 
       
              if Hoelloch_d13C_alltimepoints[x] > -1 or Hoelloch_icethk_alltimepoints[x] <= glacthick:
                 Hoellochagree_indi.append(Hoelloch_age_alltimepoints[x])
                 Hoellochagree_indi_y.append(1)
                    
           for u in range(0,len(bins_start)):
               a = np.array(Hoellochdisagree_indi)[np.where((Hoellochdisagree_indi > bins_start[u]) & (Hoellochdisagree_indi <= bins_end[u]))]
               b = np.array(Hoellochagree_indi)[np.where((Hoellochagree_indi > bins_start[u]) & (Hoellochagree_indi <= bins_end[u]))]
               if len(a) == 0 and len(b) == 0:
                   pass
               elif len(a) == 0:
                   Hoelloch_agreementratio.append(1)
                   Hoelloch_agreementratio_age.append(bins_start[u]+(sampling_step/2))
               elif len(b) == 0 or len(a) > 0:
                   Hoelloch_agreementratio.append(0)
                   Hoelloch_agreementratio_age.append(bins_start[u]+(sampling_step/2)),
               else:
                   Hoelloch_agreementratio.append(len(a)/len(b))
                   Hoelloch_agreementratio_age.append(bins_start[u]+(sampling_step/2))
               if len(a) > 0:
                   Hoelloch_disagreement.append(0)
                   Hoelloch_disagreement_age.append(bins_start[u]+(sampling_step/2))
                   
                   
               elif len(np.array(Hoellochagree_1)[np.where((Hoellochagree_1 > bins_start[u]) & (Hoellochagree_1 <= bins_end[u]))]) != 0 or len(np.array(Hoellochagree_2)[np.where((Hoellochagree_2 > bins_start[u]) & (Hoellochagree_2 <= bins_end[u]))]) != 0 or len(np.array(Hoellochagree_3)[np.where((Hoellochagree_3 > bins_start[u]) & (Hoellochagree_3 <= bins_end[u]))]) != 0:
                      Hoelloch_agreement_version.append(np.argmax([len(np.array(Hoellochagree_1)[np.where((Hoellochagree_1 > bins_start[u]) & (Hoellochagree_1 <= bins_end[u]))]), len(np.array(Hoellochagree_2)[np.where((Hoellochagree_2 > bins_start[u]) & (Hoellochagree_2 <= bins_end[u]))]), len(np.array(Hoellochagree_3)[np.where((Hoellochagree_3 > bins_start[u]) & (Hoellochagree_3 <= bins_end[u]))])]) + 1)
                      Hoelloch_agreement_version_age.append(bins_start[u]+(sampling_step/2))  
    
        if cavenames_entities[f] == 'Schneckenloch':        
           Schneckenlochdisagree_indi_y = []            
           Schneckenlochdisagree_indi = []
           Schneckenlochagree_indi_y = []            
           Schneckenlochagree_indi = []
           Schneckenlochagree_1 = []
           Schneckenlochagree_1_y = []
           Schneckenlochagree_2 = []
           Schneckenlochagree_2_y = []
           Schneckenlochagree_3 = []
           Schneckenlochagree_3_y = [] 
           for x in range(0,len(Schneckenloch_d13C_alltimepoints)):
              if Schneckenloch_d13C_alltimepoints[x] < -1 and Schneckenloch_icethk_alltimepoints[x] > glacthick:
                 Schneckenlochdisagree_indi.append(Schneckenloch_age_alltimepoints[x])
                 Schneckenlochdisagree_indi_y.append(-1)
                 
              elif Schneckenloch_d13C_alltimepoints[x] < -1 and Schneckenloch_icethk_alltimepoints[x] <= glacthick: 
                   Schneckenlochagree_1.append(Schneckenloch_age_alltimepoints[x])
                   Schneckenlochagree_1_y.append(1)
              elif Schneckenloch_d13C_alltimepoints[x] > -1 and Schneckenloch_icethk_alltimepoints[x] > glacthick: 
                   Schneckenlochagree_2.append(Schneckenloch_age_alltimepoints[x])
                   Schneckenlochagree_2_y.append(2)
              elif Schneckenloch_d13C_alltimepoints[x] > -1 and Schneckenloch_icethk_alltimepoints[x] <= glacthick: 
                   Schneckenlochagree_3.append(Schneckenloch_age_alltimepoints[x])
                   Schneckenlochagree_3_y.append(3)             
                
              if Schneckenloch_d13C_alltimepoints[x] > -1 or Schneckenloch_icethk_alltimepoints[x] <= glacthick:
                 Schneckenlochagree_indi.append(Schneckenloch_age_alltimepoints[x])
                 Schneckenlochagree_indi_y.append(1)
                    
           for u in range(0,len(bins_start)):
               a = np.array(Schneckenlochdisagree_indi)[np.where((Schneckenlochdisagree_indi > bins_start[u]) & (Schneckenlochdisagree_indi <= bins_end[u]))]
               b = np.array(Schneckenlochagree_indi)[np.where((Schneckenlochagree_indi > bins_start[u]) & (Schneckenlochagree_indi <= bins_end[u]))]
               if len(a) == 0 and len(b) == 0:
                   pass
               elif len(a) == 0:
                   Schneckenloch_agreementratio.append(1)
                   Schneckenloch_agreementratio_age.append(bins_start[u]+(sampling_step/2))
               elif len(b) == 0 or len(a) > 0:
                   Schneckenloch_agreementratio.append(0)
                   Schneckenloch_agreementratio_age.append(bins_start[u]+(sampling_step/2)),
               else:
                   Schneckenloch_agreementratio.append(len(a)/len(b))
                   Schneckenloch_agreementratio_age.append(bins_start[u]+(sampling_step/2))
               if len(a) > 0:
                   Schneckenloch_disagreement.append(0)
                   Schneckenloch_disagreement_age.append(bins_start[u]+(sampling_step/2))   
                   
               elif len(np.array(Schneckenlochagree_1)[np.where((Schneckenlochagree_1 > bins_start[u]) & (Schneckenlochagree_1 <= bins_end[u]))]) != 0 or len(np.array(Schneckenlochagree_2)[np.where((Schneckenlochagree_2 > bins_start[u]) & (Schneckenlochagree_2 <= bins_end[u]))]) != 0 or len(np.array(Schneckenlochagree_3)[np.where((Schneckenlochagree_3 > bins_start[u]) & (Schneckenlochagree_3 <= bins_end[u]))]) != 0:
                      Schneckenloch_agreement_version.append(np.argmax([len(np.array(Schneckenlochagree_1)[np.where((Schneckenlochagree_1 > bins_start[u]) & (Schneckenlochagree_1 <= bins_end[u]))]), len(np.array(Schneckenlochagree_2)[np.where((Schneckenlochagree_2 > bins_start[u]) & (Schneckenlochagree_2 <= bins_end[u]))]), len(np.array(Schneckenlochagree_3)[np.where((Schneckenlochagree_3 > bins_start[u]) & (Schneckenlochagree_3 <= bins_end[u]))])]) + 1)
                      Schneckenloch_agreement_version_age.append(bins_start[u]+(sampling_step/2))  

        if cavenames_entities[f] == 'Grete-Ruth shaft':        
           Gretedisagree_indi_y = []            
           Gretedisagree_indi = []
           Greteagree_indi_y = []            
           Greteagree_indi = []
           Greteagree_1 = []
           Greteagree_1_y = []
           Greteagree_2 = []
           Greteagree_2_y = []
           Greteagree_3 = []
           Greteagree_3_y = [] 
           for x in range(0,len(Grete_d13C_alltimepoints)):
              if Grete_d13C_alltimepoints[x] < -1 and Grete_icethk_alltimepoints[x] > glacthick:
                 Gretedisagree_indi.append(Grete_age_alltimepoints[x])
                 Gretedisagree_indi_y.append(-1)
                 
              elif Grete_d13C_alltimepoints[x] < -1 and Grete_icethk_alltimepoints[x] <= glacthick: 
                   Greteagree_1.append(Grete_age_alltimepoints[x])
                   Greteagree_1_y.append(1)
              elif Grete_d13C_alltimepoints[x] > -1 and Grete_icethk_alltimepoints[x] > glacthick: 
                   Greteagree_2.append(Grete_age_alltimepoints[x])
                   Greteagree_2_y.append(2)
              elif Grete_d13C_alltimepoints[x] > -1 and Grete_icethk_alltimepoints[x] <= glacthick: 
                   Greteagree_3.append(Grete_age_alltimepoints[x])
                   Greteagree_3_y.append(3)             
                 
              if Grete_d13C_alltimepoints[x] > -1 or Grete_icethk_alltimepoints[x] <= glacthick:
                 Greteagree_indi.append(Grete_age_alltimepoints[x])
                 Greteagree_indi_y.append(1)
                    
           for u in range(0,len(bins_start)):
               a = np.array(Gretedisagree_indi)[np.where((Gretedisagree_indi > bins_start[u]) & (Gretedisagree_indi <= bins_end[u]))]
               b = np.array(Greteagree_indi)[np.where((Greteagree_indi > bins_start[u]) & (Greteagree_indi <= bins_end[u]))]
               if len(a) == 0 and len(b) == 0:
                   pass
               elif len(a) == 0:
                   Grete_agreementratio.append(1)
                   Grete_agreementratio_age.append(bins_start[u]+(sampling_step/2))
               elif len(b) == 0 or len(a) > 0:
                   Grete_agreementratio.append(0)
                   Grete_agreementratio_age.append(bins_start[u]+(sampling_step/2)),
               else:
                   Grete_agreementratio.append(len(a)/len(b))
                   Grete_agreementratio_age.append(bins_start[u]+(sampling_step/2))
               if len(a) > 0:
                   Grete_disagreement.append(0)
                   Grete_disagreement_age.append(bins_start[u]+(sampling_step/2))
                   
               elif len(np.array(Greteagree_1)[np.where((Greteagree_1 > bins_start[u]) & (Greteagree_1 <= bins_end[u]))]) != 0 or len(np.array(Greteagree_2)[np.where((Greteagree_2 > bins_start[u]) & (Greteagree_2 <= bins_end[u]))]) != 0 or len(np.array(Greteagree_3)[np.where((Greteagree_3 > bins_start[u]) & (Greteagree_3 <= bins_end[u]))]) != 0:
                      Grete_agreement_version.append(np.argmax([len(np.array(Greteagree_1)[np.where((Greteagree_1 > bins_start[u]) & (Greteagree_1 <= bins_end[u]))]), len(np.array(Greteagree_2)[np.where((Greteagree_2 > bins_start[u]) & (Greteagree_2 <= bins_end[u]))]), len(np.array(Greteagree_3)[np.where((Greteagree_3 > bins_start[u]) & (Greteagree_3 <= bins_end[u]))])]) + 1)
                      Grete_agreement_version_age.append(bins_start[u]+(sampling_step/2))  

        if cavenames_entities[f] == 'Gassel':        
           Gasseldisagree_indi_y = []            
           Gasseldisagree_indi = []
           Gasselagree_indi_y = []            
           Gasselagree_indi = []
           Gasselagree_1 = []
           Gasselagree_1_y = []
           Gasselagree_2 = []
           Gasselagree_2_y = []
           Gasselagree_3 = []
           Gasselagree_3_y = [] 
           for x in range(0,len(Gassel_d13C_alltimepoints)):
              if Gassel_d13C_alltimepoints[x] < -1 and Gassel_icethk_alltimepoints[x] > glacthick:
                 Gasseldisagree_indi.append(Gassel_age_alltimepoints[x])
                 Gasseldisagree_indi_y.append(-1)
                 
              elif Gassel_d13C_alltimepoints[x] < -1 and Gassel_icethk_alltimepoints[x] <= glacthick: 
                   Gasselagree_1.append(Gassel_age_alltimepoints[x])
                   Gasselagree_1_y.append(1)
              elif Gassel_d13C_alltimepoints[x] > -1 and Gassel_icethk_alltimepoints[x] > glacthick: 
                   Gasselagree_2.append(Gassel_age_alltimepoints[x])
                   Gasselagree_2_y.append(2)
              elif Gassel_d13C_alltimepoints[x] > -1 and Gassel_icethk_alltimepoints[x] <= glacthick: 
                   Gasselagree_3.append(Gassel_age_alltimepoints[x])
                   Gasselagree_3_y.append(3)             
                
              if Gassel_d13C_alltimepoints[x] > -1 or Gassel_icethk_alltimepoints[x] <= glacthick:
                 Gasselagree_indi.append(Gassel_age_alltimepoints[x])
                 Gasselagree_indi_y.append(1)
                    
           for u in range(0,len(bins_start)):
               a = np.array(Gasseldisagree_indi)[np.where((Gasseldisagree_indi > bins_start[u]) & (Gasseldisagree_indi <= bins_end[u]))]
               b = np.array(Gasselagree_indi)[np.where((Gasselagree_indi > bins_start[u]) & (Gasselagree_indi <= bins_end[u]))]
               if len(a) == 0 and len(b) == 0:
                   pass
               elif len(a) == 0:
                   Gassel_agreementratio.append(1)
                   Gassel_agreementratio_age.append(bins_start[u]+(sampling_step/2))
               elif len(b) == 0 or len(a) > 0:
                   Gassel_agreementratio.append(0)
                   Gassel_agreementratio_age.append(bins_start[u]+(sampling_step/2)),
               else:
                   Gassel_agreementratio.append(len(a)/len(b))
                   Gassel_agreementratio_age.append(bins_start[u]+(sampling_step/2))
               if len(a) > 0:
                   Gassel_disagreement.append(0)
                   Gassel_disagreement_age.append(bins_start[u]+(sampling_step/2)) 
                   
               elif len(np.array(Gasselagree_1)[np.where((Gasselagree_1 > bins_start[u]) & (Gasselagree_1 <= bins_end[u]))]) != 0 or len(np.array(Gasselagree_2)[np.where((Gasselagree_2 > bins_start[u]) & (Gasselagree_2 <= bins_end[u]))]) != 0 or len(np.array(Gasselagree_3)[np.where((Gasselagree_3 > bins_start[u]) & (Gasselagree_3 <= bins_end[u]))]) != 0:
                      Gassel_agreement_version.append(np.argmax([len(np.array(Gasselagree_1)[np.where((Gasselagree_1 > bins_start[u]) & (Gasselagree_1 <= bins_end[u]))]), len(np.array(Gasselagree_2)[np.where((Gasselagree_2 > bins_start[u]) & (Gasselagree_2 <= bins_end[u]))]), len(np.array(Gasselagree_3)[np.where((Gasselagree_3 > bins_start[u]) & (Gasselagree_3 <= bins_end[u]))])]) + 1)
                      Gassel_agreement_version_age.append(bins_start[u]+(sampling_step/2))                  

        if cavenames_entities[f] == 'Schratten':        
           Schrattendisagree_indi_y = []            
           Schrattendisagree_indi = []
           Schrattenagree_indi_y = []            
           Schrattenagree_indi = []
           Schrattenagree_1 = []
           Schrattenagree_1_y = []
           Schrattenagree_2 = []
           Schrattenagree_2_y = []
           Schrattenagree_3 = []
           Schrattenagree_3_y = [] 
           for x in range(0,len(Schratten_d13C_alltimepoints)):
              if Schratten_d13C_alltimepoints[x] < -1 and Schratten_icethk_alltimepoints[x] > glacthick:
                 Schrattendisagree_indi.append(Schratten_age_alltimepoints[x])
                 Schrattendisagree_indi_y.append(-1)
            
              elif Schratten_d13C_alltimepoints[x] < -1 and Schratten_icethk_alltimepoints[x] <= glacthick: 
                   Schrattenagree_1.append(Schratten_age_alltimepoints[x])
                   Schrattenagree_1_y.append(1)
              elif Schratten_d13C_alltimepoints[x] > -1 and Schratten_icethk_alltimepoints[x] > glacthick: 
                   Schrattenagree_2.append(Schratten_age_alltimepoints[x])
                   Schrattenagree_2_y.append(2)
              elif Schratten_d13C_alltimepoints[x] > -1 and Schratten_icethk_alltimepoints[x] <= glacthick: 
                   Schrattenagree_3.append(Schratten_age_alltimepoints[x])
                   Schrattenagree_3_y.append(3)             
            
              if Schratten_d13C_alltimepoints[x] > -1 or Schratten_icethk_alltimepoints[x] <= glacthick:
                 Schrattenagree_indi.append(Schratten_age_alltimepoints[x])
                 Schrattenagree_indi_y.append(1)
                    
           for u in range(0,len(bins_start)):
               a = np.array(Schrattendisagree_indi)[np.where((Schrattendisagree_indi > bins_start[u]) & (Schrattendisagree_indi <= bins_end[u]))]
               b = np.array(Schrattenagree_indi)[np.where((Schrattenagree_indi > bins_start[u]) & (Schrattenagree_indi <= bins_end[u]))]
               if len(a) == 0 and len(b) == 0:
                   pass
               elif len(a) == 0:
                   Schratten_agreementratio.append(1)
                   Schratten_agreementratio_age.append(bins_start[u]+(sampling_step/2))
               elif len(b) == 0 or len(a) > 0:
                   Schratten_agreementratio.append(0)
                   Schratten_agreementratio_age.append(bins_start[u]+(sampling_step/2)),
               else:
                   Schratten_agreementratio.append(len(a)/len(b))
                   Schratten_agreementratio_age.append(bins_start[u]+(sampling_step/2))
               if len(a) > 0:
                   Schratten_disagreement.append(0)
                   Schratten_disagreement_age.append(bins_start[u]+(sampling_step/2))
                   
               elif len(np.array(Schrattenagree_1)[np.where((Schrattenagree_1 > bins_start[u]) & (Schrattenagree_1 <= bins_end[u]))]) != 0 or len(np.array(Schrattenagree_2)[np.where((Schrattenagree_2 > bins_start[u]) & (Schrattenagree_2 <= bins_end[u]))]) != 0 or len(np.array(Schrattenagree_3)[np.where((Schrattenagree_3 > bins_start[u]) & (Schrattenagree_3 <= bins_end[u]))]) != 0:
                      Schratten_agreement_version.append(np.argmax([len(np.array(Schrattenagree_1)[np.where((Schrattenagree_1 > bins_start[u]) & (Schrattenagree_1 <= bins_end[u]))]), len(np.array(Schrattenagree_2)[np.where((Schrattenagree_2 > bins_start[u]) & (Schrattenagree_2 <= bins_end[u]))]), len(np.array(Schrattenagree_3)[np.where((Schrattenagree_3 > bins_start[u]) & (Schrattenagree_3 <= bins_end[u]))])]) + 1)
                      Schratten_agreement_version_age.append(bins_start[u]+(sampling_step/2))     

        if cavenames_entities[f] == 'Neotektonik':        
           Neotektonikdisagree_indi_y = []            
           Neotektonikdisagree_indi = []
           Neotektonikagree_indi_y = []            
           Neotektonikagree_indi = []
           Neotektonikagree_1 = []
           Neotektonikagree_1_y = []
           Neotektonikagree_2 = []
           Neotektonikagree_2_y = []
           Neotektonikagree_3 = []
           Neotektonikagree_3_y = [] 
           for x in range(0,len(Neotektonik_d13C_alltimepoints)):
              if Neotektonik_d13C_alltimepoints[x] < -1 and Neotektonik_icethk_alltimepoints[x] > glacthick:
                 Neotektonikdisagree_indi.append(Neotektonik_age_alltimepoints[x])
                 Neotektonikdisagree_indi_y.append(-1)
                
              elif Neotektonik_d13C_alltimepoints[x] < -1 and Neotektonik_icethk_alltimepoints[x] <= glacthick: 
                   Neotektonikagree_1.append(Neotektonik_age_alltimepoints[x])
                   Neotektonikagree_1_y.append(1)
              elif Neotektonik_d13C_alltimepoints[x] > -1 and Neotektonik_icethk_alltimepoints[x] > glacthick: 
                   Neotektonikagree_2.append(Neotektonik_age_alltimepoints[x])
                   Neotektonikagree_2_y.append(2)
              elif Neotektonik_d13C_alltimepoints[x] > -1 and Neotektonik_icethk_alltimepoints[x] <= glacthick: 
                   Neotektonikagree_3.append(Neotektonik_age_alltimepoints[x])
                   Neotektonikagree_3_y.append(3)             
                 
              if Neotektonik_d13C_alltimepoints[x] > -1 or Neotektonik_icethk_alltimepoints[x] <= glacthick:
                 Neotektonikagree_indi.append(Neotektonik_age_alltimepoints[x])
                 Neotektonikagree_indi_y.append(1)
                    
           for u in range(0,len(bins_start)):
               a = np.array(Neotektonikdisagree_indi)[np.where((Neotektonikdisagree_indi > bins_start[u]) & (Neotektonikdisagree_indi <= bins_end[u]))]
               b = np.array(Neotektonikagree_indi)[np.where((Neotektonikagree_indi > bins_start[u]) & (Neotektonikagree_indi <= bins_end[u]))]
               if len(a) == 0 and len(b) == 0:
                   pass
               elif len(a) == 0:
                   Neotektonik_agreementratio.append(1)
                   Neotektonik_agreementratio_age.append(bins_start[u]+(sampling_step/2))
               elif len(b) == 0 or len(a) > 0:
                   Neotektonik_agreementratio.append(0)
                   Neotektonik_agreementratio_age.append(bins_start[u]+(sampling_step/2)),
               else:
                   Neotektonik_agreementratio.append(len(a)/len(b))
                   Neotektonik_agreementratio_age.append(bins_start[u]+(sampling_step/2))
               if len(a) > 0:
                   Neotektonik_disagreement.append(0)
                   Neotektonik_disagreement_age.append(bins_start[u]+(sampling_step/2))
    
               elif len(np.array(Neotektonikagree_1)[np.where((Neotektonikagree_1 > bins_start[u]) & (Neotektonikagree_1 <= bins_end[u]))]) != 0 or len(np.array(Neotektonikagree_2)[np.where((Neotektonikagree_2 > bins_start[u]) & (Neotektonikagree_2 <= bins_end[u]))]) != 0 or len(np.array(Neotektonikagree_3)[np.where((Neotektonikagree_3 > bins_start[u]) & (Neotektonikagree_3 <= bins_end[u]))]) != 0:
                      Neotektonik_agreement_version.append(np.argmax([len(np.array(Neotektonikagree_1)[np.where((Neotektonikagree_1 > bins_start[u]) & (Neotektonikagree_1 <= bins_end[u]))]), len(np.array(Neotektonikagree_2)[np.where((Neotektonikagree_2 > bins_start[u]) & (Neotektonikagree_2 <= bins_end[u]))]), len(np.array(Neotektonikagree_3)[np.where((Neotektonikagree_3 > bins_start[u]) & (Neotektonikagree_3 <= bins_end[u]))])]) + 1)
                      Neotektonik_agreement_version_age.append(bins_start[u]+(sampling_step/2))     
    
        if cavenames_entities[f] == 'Klaus-Cramer':        
           Klausdisagree_indi_y = []            
           Klausdisagree_indi = []
           Klausagree_indi_y = []            
           Klausagree_indi = []
           Klausagree_1 = []
           Klausagree_1_y = []
           Klausagree_2 = []
           Klausagree_2_y = []
           Klausagree_3 = []
           Klausagree_3_y = [] 
           for x in range(0,len(Klaus_d13C_alltimepoints)):
              if Klaus_d13C_alltimepoints[x] < -1 and Klaus_icethk_alltimepoints[x] > glacthick:
                 Klausdisagree_indi.append(Klaus_age_alltimepoints[x])
                 Klausdisagree_indi_y.append(-1)
                 
              elif Klaus_d13C_alltimepoints[x] < -1 and Klaus_icethk_alltimepoints[x] <= glacthick: 
                   Klausagree_1.append(Klaus_age_alltimepoints[x])
                   Klausagree_1_y.append(1)
              elif Klaus_d13C_alltimepoints[x] > -1 and Klaus_icethk_alltimepoints[x] > glacthick: 
                   Klausagree_2.append(Klaus_age_alltimepoints[x])
                   Klausagree_2_y.append(2)
              elif Klaus_d13C_alltimepoints[x] > -1 and Klaus_icethk_alltimepoints[x] <= glacthick: 
                   Klausagree_3.append(Klaus_age_alltimepoints[x])
                   Klausagree_3_y.append(3)             
                
              if Klaus_d13C_alltimepoints[x] > -1 or Klaus_icethk_alltimepoints[x] <= glacthick:
                 Klausagree_indi.append(Klaus_age_alltimepoints[x])
                 Klausagree_indi_y.append(1)
                    
           for u in range(0,len(bins_start)):
               a = np.array(Klausdisagree_indi)[np.where((Klausdisagree_indi > bins_start[u]) & (Klausdisagree_indi <= bins_end[u]))]
               b = np.array(Klausagree_indi)[np.where((Klausagree_indi > bins_start[u]) & (Klausagree_indi <= bins_end[u]))]
               if len(a) == 0 and len(b) == 0:
                   pass
               elif len(a) == 0:
                   Klaus_agreementratio.append(1)
                   Klaus_agreementratio_age.append(bins_start[u]+(sampling_step/2))
               elif len(b) == 0 or len(a) > 0:
                   Klaus_agreementratio.append(0)
                   Klaus_agreementratio_age.append(bins_start[u]+(sampling_step/2)),
               else:
                   Klaus_agreementratio.append(len(a)/len(b))
                   Klaus_agreementratio_age.append(bins_start[u]+(sampling_step/2))
               if len(a) > 0:
                   Klaus_disagreement.append(0)
                   Klaus_disagreement_age.append(bins_start[u]+(sampling_step/2))
                   
               elif len(np.array(Klausagree_1)[np.where((Klausagree_1 > bins_start[u]) & (Klausagree_1 <= bins_end[u]))]) != 0 or len(np.array(Klausagree_2)[np.where((Klausagree_2 > bins_start[u]) & (Klausagree_2 <= bins_end[u]))]) != 0 or len(np.array(Klausagree_3)[np.where((Klausagree_3 > bins_start[u]) & (Klausagree_3 <= bins_end[u]))]) != 0:
                      Klaus_agreement_version.append(np.argmax([len(np.array(Klausagree_1)[np.where((Klausagree_1 > bins_start[u]) & (Klausagree_1 <= bins_end[u]))]), len(np.array(Klausagree_2)[np.where((Klausagree_2 > bins_start[u]) & (Klausagree_2 <= bins_end[u]))]), len(np.array(Klausagree_3)[np.where((Klausagree_3 > bins_start[u]) & (Klausagree_3 <= bins_end[u]))])]) + 1)
                      Klaus_agreement_version_age.append(bins_start[u]+(sampling_step/2))               

    
        if cavenames_entities[f] == 'Beatus':        
           Beatusdisagree_indi_y = []            
           Beatusdisagree_indi = []
           Beatusagree_indi_y = []            
           Beatusagree_indi = []
           Beatusagree_1 = []
           Beatusagree_1_y = []
           Beatusagree_2 = []
           Beatusagree_2_y = []
           Beatusagree_3 = []
           Beatusagree_3_y = [] 
           for x in range(0,len(Beatus_d13C_alltimepoints)):
              if Beatus_d13C_alltimepoints[x] < -1 and Beatus_icethk_alltimepoints[x] > glacthick:
                 Beatusdisagree_indi.append(Beatus_age_alltimepoints[x])
                 Beatusdisagree_indi_y.append(-1)
                
              elif Beatus_d13C_alltimepoints[x] < -1 and Beatus_icethk_alltimepoints[x] <= glacthick: 
                   Beatusagree_1.append(Beatus_age_alltimepoints[x])
                   Beatusagree_1_y.append(1)
              elif Beatus_d13C_alltimepoints[x] > -1 and Beatus_icethk_alltimepoints[x] > glacthick: 
                   Beatusagree_2.append(Beatus_age_alltimepoints[x])
                   Beatusagree_2_y.append(2)
              elif Beatus_d13C_alltimepoints[x] > -1 and Beatus_icethk_alltimepoints[x] <= glacthick: 
                   Beatusagree_3.append(Beatus_age_alltimepoints[x])
                   Beatusagree_3_y.append(3)             
                
              if Beatus_d13C_alltimepoints[x] > -1 or Beatus_icethk_alltimepoints[x] <= glacthick:
                 Beatusagree_indi.append(Beatus_age_alltimepoints[x])
                 Beatusagree_indi_y.append(1)
                    
           for u in range(0,len(bins_start)):
               a = np.array(Beatusdisagree_indi)[np.where((Beatusdisagree_indi > bins_start[u]) & (Beatusdisagree_indi <= bins_end[u]))]
               b = np.array(Beatusagree_indi)[np.where((Beatusagree_indi > bins_start[u]) & (Beatusagree_indi <= bins_end[u]))]
               if len(a) == 0 and len(b) == 0:
                   pass
               elif len(a) == 0:
                   Beatus_agreementratio.append(1)
                   Beatus_agreementratio_age.append(bins_start[u]+(sampling_step/2))
               elif len(b) == 0 or len(a) > 0:
                   Beatus_agreementratio.append(0)
                   Beatus_agreementratio_age.append(bins_start[u]+(sampling_step/2)),
               else:
                   Beatus_agreementratio.append(len(a)/len(b))
                   Beatus_agreementratio_age.append(bins_start[u]+(sampling_step/2))
               if len(a) > 0:
                   Beatus_disagreement.append(0)
                   Beatus_disagreement_age.append(bins_start[u]+(sampling_step/2))
    
               elif len(np.array(Beatusagree_1)[np.where((Beatusagree_1 > bins_start[u]) & (Beatusagree_1 <= bins_end[u]))]) != 0 or len(np.array(Beatusagree_2)[np.where((Beatusagree_2 > bins_start[u]) & (Beatusagree_2 <= bins_end[u]))]) != 0 or len(np.array(Beatusagree_3)[np.where((Beatusagree_3 > bins_start[u]) & (Beatusagree_3 <= bins_end[u]))]) != 0:
                      Beatus_agreement_version.append(np.argmax([len(np.array(Beatusagree_1)[np.where((Beatusagree_1 > bins_start[u]) & (Beatusagree_1 <= bins_end[u]))]), len(np.array(Beatusagree_2)[np.where((Beatusagree_2 > bins_start[u]) & (Beatusagree_2 <= bins_end[u]))]), len(np.array(Beatusagree_3)[np.where((Beatusagree_3 > bins_start[u]) & (Beatusagree_3 <= bins_end[u]))])]) + 1)
                      Beatus_agreement_version_age.append(bins_start[u]+(sampling_step/2))

    Spannagel_agreement_version_x.append(Spannagel_agreement_version)
    Spannagel_agreement_version_age_x.append(Spannagel_agreement_version_age)
    Baschg_agreement_version_x.append(Baschg_agreement_version)
    Baschg_agreement_version_age_x.append(Baschg_agreement_version_age)
    SiebenHengste_agreement_version_x.append(SiebenHengste_agreement_version)
    SiebenHengste_agreement_version_age_x.append(SiebenHengste_agreement_version_age)
    Entrische_agreement_version_x.append(Entrische_agreement_version)
    Entrische_agreement_version_age_x.append(Entrische_agreement_version_age)
    Hoelloch_agreement_version_x.append(Hoelloch_agreement_version)
    Hoelloch_agreement_version_age_x.append(Hoelloch_agreement_version_age)
    Schneckenloch_agreement_version_x.append(Schneckenloch_agreement_version)
    Schneckenloch_agreement_version_age_x.append(Schneckenloch_agreement_version_age)
    Grete_agreement_version_x.append(Grete_agreement_version)
    Grete_agreement_version_age_x.append(Grete_agreement_version_age)
    Gassel_agreement_version_x.append(Gassel_agreement_version)
    Gassel_agreement_version_age_x.append(Gassel_agreement_version_age)
    Schratten_agreement_version_x.append(Schratten_agreement_version)
    Schratten_agreement_version_age_x.append(Schratten_agreement_version_age)
    Neotektonik_agreement_version_x.append(Neotektonik_agreement_version)
    Neotektonik_agreement_version_age_x.append(Neotektonik_agreement_version_age)
    Klaus_agreement_version_x.append(Klaus_agreement_version)
    Klaus_agreement_version_age_x.append(Klaus_agreement_version_age)
    Beatus_agreement_version_x.append(Beatus_agreement_version)
    Beatus_agreement_version_age_x.append(Beatus_agreement_version_age)
    
    Spannagel_disagreement_x.append(Spannagel_disagreement)
    Spannagel_disagreement_age_x.append(Spannagel_disagreement_age)
    Baschg_disagreement_x.append(Baschg_disagreement)
    Baschg_disagreement_age_x.append(Baschg_disagreement_age)
    SiebenHengste_disagreement_x.append(SiebenHengste_disagreement)
    SiebenHengste_disagreement_age_x.append(SiebenHengste_disagreement_age)
    Entrische_disagreement_x.append(Entrische_disagreement)
    Entrische_disagreement_age_x.append(Entrische_disagreement_age)
    Hoelloch_disagreement_x.append(Hoelloch_disagreement)
    Hoelloch_disagreement_age_x.append(Hoelloch_disagreement_age)
    Schneckenloch_disagreement_x.append(Schneckenloch_disagreement)
    Schneckenloch_disagreement_age_x.append(Schneckenloch_disagreement_age)
    Grete_disagreement_x.append(Grete_disagreement)
    Grete_disagreement_age_x.append(Grete_disagreement_age)
    Gassel_disagreement_x.append(Gassel_disagreement)
    Gassel_disagreement_age_x.append(Gassel_disagreement_age)
    Schratten_disagreement_x.append(Schratten_disagreement)
    Schratten_disagreement_age_x.append(Schratten_disagreement_age)
    Neotektonik_disagreement_x.append(Neotektonik_disagreement)
    Neotektonik_disagreement_age_x.append(Neotektonik_disagreement_age)
    Klaus_disagreement_x.append(Klaus_disagreement)
    Klaus_disagreement_age_x.append(Klaus_disagreement_age)
    Beatus_disagreement_x.append(Beatus_disagreement)
    Beatus_disagreement_age_x.append(Beatus_disagreement_age)
    

cavenames_entities = ["Spannagel", "Baschg", "Sieben Hengste", "Schafsloch", "Entrische Kirche", "Hoelloch im Mahdtal", "Schneckenloch", "Grete-Ruth shaft", "Gassel", "Schratten", "Neotektonik", 'Klaus-Cramer', 'Beatus']
elevation = [2512, 870, 1883, 1960, 1040, 1560, 1568, 1491, 1196, 1862, 1862, 2021, 807]
markerrr = ["*", "v", "^","P","<",">","o","d","X","D","s", "p", "H"]

num_rows = 11*len(simus)#77 
num = 0#4
sss = 80 #markersize
nn = 4 # number of different agreement versions
new_viridis = cm.get_cmap('viridis_r', nn)
v = new_viridis.colors
v[2] = [0.12, 0.56, 1, 1]
new_viridis = LinearSegmentedColormap.from_list("eh", v, N=nn)
mpl.style.use('default')
fig, axs = plt.subplots(nrows=num_rows, ncols=1, sharex=True, gridspec_kw={'hspace': 0}, figsize=(12, 1.5))
plt.subplots_adjust(top=10, bottom = 1)
t = -1
i = 0
for ax in axs.flat:
    t = t+1

    if t < 8:
        img = ax.scatter(np.concatenate([Spannagel_disagreement_age_x[i], Spannagel_agreement_version_age_x[i]]), np.concatenate([Spannagel_disagreement_x[i], np.zeros(len(Spannagel_agreement_version_x[i]))]), c = np.concatenate([Spannagel_disagreement_x[i], Spannagel_agreement_version_x[i]]), marker= markerrr[0], cmap=new_viridis, edgecolor="black",s=sss, linewidth=0.2, vmin=0, vmax=3) 
        i = i+1
        
    if t >= 0 + 8 and t < 8 + 8:
        if t == 8:
            i = 0
        img = ax.scatter(np.concatenate([Klaus_disagreement_age_x[i], Klaus_agreement_version_age_x[i]]), np.concatenate([Klaus_disagreement_x[i], np.zeros(len(Klaus_agreement_version_x[i]))]), c = np.concatenate([Klaus_disagreement_x[i], Klaus_agreement_version_x[i]]), marker= markerrr[11], cmap=new_viridis, edgecolor="black",s=sss, linewidth=0.2, vmin=0, vmax=3)
        i = i+1
        
    if t >= 8 + 8 and t < 16 + 8:       
        if t == 16:
            i = 0
        img = ax.scatter(np.concatenate([SiebenHengste_disagreement_age_x[i], SiebenHengste_agreement_version_age_x[i]]), np.concatenate([SiebenHengste_disagreement_x[i], np.zeros(len(SiebenHengste_agreement_version_x[i]))]), c = np.concatenate([SiebenHengste_disagreement_x[i], SiebenHengste_agreement_version_x[i]]), marker= markerrr[2], cmap=new_viridis, edgecolor="black",s=sss, linewidth=0.2, vmin=0, vmax=3)  
        i = i+1
        
    if t >= 16 + 8 and t < 24 + 8:   
        if t == 24:
            i = 0
        img = ax.scatter(np.concatenate([Schratten_disagreement_age_x[i], Schratten_agreement_version_age_x[i]]), np.concatenate([Schratten_disagreement_x[i], np.zeros(len(Schratten_agreement_version_x[i]))]), c = np.concatenate([Schratten_disagreement_x[i], Schratten_agreement_version_x[i]]), marker= markerrr[9], cmap=new_viridis, edgecolor="black",s=sss, linewidth=0.2, vmin=0, vmax=3)
        i = i+1
        
    if t >= 24 + 8 and t < 32 + 8:         
        if t == 32:
            i = 0
        img = ax.scatter(np.concatenate([Schneckenloch_disagreement_age_x[i], Schneckenloch_agreement_version_age_x[i]]), np.concatenate([Schneckenloch_disagreement_x[i], np.zeros(len(Schneckenloch_agreement_version_x[i]))]), c = np.concatenate([Schneckenloch_disagreement_x[i], Schneckenloch_agreement_version_x[i]]), marker= markerrr[6], cmap=new_viridis, edgecolor="black",s=sss, linewidth=0.2, vmin=0, vmax=3)
        i = i+1
        
    if t >= 32 + 8 and t < 40 + 8: 
        if t == 40:
            i = 0
        img = ax.scatter(np.concatenate([Hoelloch_disagreement_age_x[i], Hoelloch_agreement_version_age_x[i]]), np.concatenate([Hoelloch_disagreement_x[i], np.zeros(len(Hoelloch_agreement_version_x[i]))]), c = np.concatenate([Hoelloch_disagreement_x[i], Hoelloch_agreement_version_x[i]]), marker= markerrr[5], cmap=new_viridis, edgecolor="black",s=sss, linewidth=0.2, vmin=0, vmax=3)
        i = i+1
        
    if t >= 40 + 8 and t < 48 + 8:        
        if t == 48:
            i = 0
        img = ax.scatter(np.concatenate([Grete_disagreement_age_x[i], Grete_agreement_version_age_x[i]]), np.concatenate([Grete_disagreement_x[i], np.zeros(len(Grete_agreement_version_x[i]))]), c = np.concatenate([Grete_disagreement_x[i], Grete_agreement_version_x[i]]), marker= markerrr[7], cmap=new_viridis, edgecolor="black",s=sss, linewidth=0.2, vmin=0, vmax=3)
        i = i+1

    if  t >= 48 + 8 and t < 56 + 8:    
        if t == 56:
            i = 0
        img = ax.scatter(np.concatenate([Gassel_disagreement_age_x[i], Gassel_agreement_version_age_x[i]]), np.concatenate([Gassel_disagreement_x[i], np.zeros(len(Gassel_agreement_version_x[i]))]), c = np.concatenate([Gassel_disagreement_x[i], Gassel_agreement_version_x[i]]), marker= markerrr[8], cmap=new_viridis, edgecolor="black",s=sss, linewidth=0.2, vmin=0, vmax=3)
        i = i+1

    if t >= 56 + 8 and t < 64 + 8:    
        if t == 64:
            i = 0
        img = ax.scatter(np.concatenate([Beatus_disagreement_age_x[i], Beatus_agreement_version_age_x[i]]), np.concatenate([Beatus_disagreement_x[i], np.zeros(len(Beatus_agreement_version_x[i]))]), c = np.concatenate([Beatus_disagreement_x[i], Beatus_agreement_version_x[i]]), marker= markerrr[12], cmap=new_viridis, edgecolor="black",s=sss, linewidth=0.2, vmin=0, vmax=3)
        i = i+1
        
    if t >= 64 + 8 and t < 72 + 8:   
        if t == 72:
            i = 0
        img = ax.scatter(np.concatenate([Entrische_disagreement_age_x[i], Entrische_agreement_version_age_x[i]]), np.concatenate([Entrische_disagreement_x[i], np.zeros(len(Entrische_agreement_version_x[i]))]), c = np.concatenate([Entrische_disagreement_x[i], Entrische_agreement_version_x[i]]), marker= markerrr[4], cmap=new_viridis, edgecolor="black",s=sss, linewidth=0.2, vmin=0, vmax=3)             
        i = i+1
                
    if t >= 72 + 8 and t < 80 + 8:      
        if t == 80:
            i = 0
        img = ax.scatter(np.concatenate([Baschg_disagreement_age_x[i], Baschg_agreement_version_age_x[i]]), np.concatenate([Baschg_disagreement_x[i], np.zeros(len(Baschg_agreement_version_x[i]))]), c = np.concatenate([Baschg_disagreement_x[i], Baschg_agreement_version_x[i]]), marker= markerrr[1], cmap=new_viridis, edgecolor="black",s=sss, linewidth=0.2, vmin=0, vmax=3) 
        i = i+1
                        
    if t == num_rows-1:
        cbar_ax = fig.add_axes([0.85, 0.15, 0.05, 0.7])
        cbar = fig.colorbar(img, ax=axs.ravel().tolist(), ticks=range(num))#cbar_ax)
    ax.set_ylim(-1,1)
    ax.set_yticks([])
    if t != 100:
        ax.spines['top'].set_visible(False)
        ax.spines['left'].set_visible(False)
        ax.spines['right'].set_visible(False)

    if t != num_rows-1:
        ax.spines['bottom'].set_visible(False)

axs[t].set_xlabel("Age [ka]", fontsize=24, weight="bold")
axs[t].set_xticks(np.arange(0,140,20))
axs[t].tick_params(axis='x', which='major', labelsize=22)
axs[t].set_xlim(-10,130)

cbar.set_ticks((0.4, 1.15, 1.85, 2.6))
cbar.ax.set_yticklabels(("Disagreement","Agreement #1", "Agreement #2", "Agreement #3"), fontsize=20, rotation = 90, ha="center", rotation_mode='anchor')
cbar.ax.yaxis.set_tick_params(pad=10)
axs[t].set_xlabel("Age [ka]", fontsize=22, weight="bold")
#plt.show()


plt.savefig("paper/AgreementIceCoverage_allsimusinterpw1km_Fig7_20230905_6kawindowsizeandsteps_corr.png", dpi=300, bbox_inches='tight', transparent=True)